@@ -43,14 +43,13 @@
 #include <cppuhelper/compbase3.hxx>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/implementationentry.hxx>
-#include <comphelper/optionalvalue.hxx>
 #include <comphelper/broadcasthelper.hxx>
 #include <comphelper/sequence.hxx>
 
 #include <animations/animationnodehelper.hxx>
 
 #include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 
 using namespace ::com::sun::star;
@@ -142,7 +141,7 @@ namespace animcore
              */
             sal_Int16							mnParagraphIndex;
 
-            /// Comparison needed for hash_map
+            /// Comparison needed for boost::unordered_map
             bool operator==( const ShapeHashKey& rRHS ) const
             {
                 return mxRef == rRHS.mxRef && mnParagraphIndex == rRHS.mnParagraphIndex;
@@ -150,7 +149,7 @@ namespace animcore
         };
 
         // A hash map which maps a XShape to the corresponding vector of initial properties
-        typedef ::std::hash_map< ShapeHashKey,
+        typedef ::boost::unordered_map< ShapeHashKey,
                                  VectorOfNamedValues,
                                  ::std::size_t (*)(const ShapeHashKey&) > XShapeHash;
 
@@ -196,8 +195,7 @@ namespace animcore
             {
                 if( !xNode.is() )
                 {
-                    OSL_ENSURE( false,
-                                "AnimCore: NodeFunctor::operator(): invalid XAnimationNode" );
+                    OSL_FAIL( "AnimCore: NodeFunctor::operator(): invalid XAnimationNode" );
                     return;
                 }
 
@@ -218,8 +216,7 @@ namespace animcore
                         // TODO(E1): I'm not too sure what to expect here...
                         if( !xIterNode->getTarget().hasValue() )
                         {
-                            OSL_ENSURE( false,
-                                        "animcore: NodeFunctor::operator(): no target on ITERATE node" );
+                            OSL_FAIL( "animcore: NodeFunctor::operator(): no target on ITERATE node" );
                             return;
                         }
                 
@@ -233,8 +230,7 @@ namespace animcore
                             // no shape provided. Maybe a ParagraphTarget?
                             if( !(xIterNode->getTarget() >>= aTarget) )
                             {
-                                OSL_ENSURE( false,
-                                            "animcore: NodeFunctor::operator(): could not extract any "
+                                OSL_FAIL( "animcore: NodeFunctor::operator(): could not extract any "
                                             "target information" );
                                 return;
                             }
@@ -244,8 +240,7 @@ namespace animcore
 
                             if( !xTargetShape.is() )
                             {
-                                OSL_ENSURE( false,
-                                            "animcore: NodeFunctor::operator(): invalid shape in ParagraphTarget" );
+                                OSL_FAIL( "animcore: NodeFunctor::operator(): invalid shape in ParagraphTarget" );
                                 return;
                             }
                         }
@@ -261,8 +256,7 @@ namespace animcore
                         if( !::anim::for_each_childNode( xNode, 
                                                          aFunctor ) )
                         {
-                            OSL_ENSURE( false, 
-                                        "AnimCore: NodeFunctor::operator(): child node iteration failed, "
+                            OSL_FAIL( "AnimCore: NodeFunctor::operator(): child node iteration failed, "
                                         "or extraneous container nodes encountered" );
                         }
                     }
@@ -321,8 +315,7 @@ namespace animcore
                                 
                                 if( !(xAnimateNode->getTarget() >>= aUnoTarget) )
                                 {
-                                    OSL_ENSURE( false,
-                                                "AnimCore: NodeFunctor::operator(): unknown target type encountered" );
+                                    OSL_FAIL( "AnimCore: NodeFunctor::operator(): unknown target type encountered" );
                                     break;
                                 }
                                 
@@ -333,8 +326,7 @@ namespace animcore
                         
                         if( !aTarget.mxRef.is() )
                         {
-                            OSL_ENSURE( false,
-                                        "AnimCore: NodeFunctor::operator(): Found target, but XShape is NULL" );
+                            OSL_FAIL( "AnimCore: NodeFunctor::operator(): Found target, but XShape is NULL" );
                             break; // invalid target XShape
                         }
                             
