@@ -106,7 +106,7 @@ BOOL GeometryIndexValueBucket::ImplCareForSpace() {
 }
 GeometryIndexValue& GeometryIndexValueBucket::operator[] (UINT32 nPos) {
     if(nPos >= nCount) {
-        DBG_ERROR("Access to Bucket out of range!");
+        OSL_FAIL("Access to Bucket out of range!");
         return *((GeometryIndexValue*)aMemArray[0]);
     }
     return *((GeometryIndexValue*)(aMemArray[(UINT16)(nPos >> nBlockShift)] + ((nPos & nMask) << nShift)));
@@ -415,7 +415,7 @@ void B3dGeometry::EndPolygon()
 |*
 \************************************************************************/
 
-sal_Bool B3dGeometry::CheckHit(const Vector3D& rFront, const Vector3D& rBack, sal_uInt16 nTol)
+sal_Bool B3dGeometry::CheckHit(const Vector3D& rFront, const Vector3D& rBack, sal_uInt16 /*nTol*/)
 {
     sal_uInt32 nPolyCounter(0L);
     sal_uInt32 nEntityCounter(0L);
