@@ -31,9 +31,7 @@
 
 #include <string.h>
 
-#if STLPORT_VERSION>=321
 #include <cstdarg>
-#endif
 
 #define _SVSTDARR_USHORTS
 #define _SVSTDARR_ULONGS
@@ -47,7 +45,7 @@
 #include "whassert.hxx"
 
 #include <tools/stream.hxx>
-#include <tools/solar.h>
+#include <bf_svtools/bf_solar.h>
 
 namespace binfilter
 {
@@ -55,7 +53,7 @@ namespace binfilter
 // STATIC DATA -----------------------------------------------------------
 
 static const USHORT nInitCount = 10; // einzelne USHORTs => 5 Paare ohne '0'
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 static ULONG nRangesCopyCount = 0;	 // wie oft wurden Ranges kopiert
 #endif
 
@@ -287,7 +285,9 @@ SfxItemSet::SfxItemSet( SfxItemPool& rPool,
 void SfxItemSet::InitRanges_Impl(const USHORT *pWhichPairTable)
 {
     DBG_CHKTHIS(SfxItemSet, 0);
-    DBG_TRACE1("SfxItemSet: Ranges-CopyCount==%ul", ++nRangesCopyCount);
+    #if OSL_DEBUG_LEVEL > 1
+    OSL_TRACE("SfxItemSet: Ranges-CopyCount==%ul", ++nRangesCopyCount);
+    #endif
 
     USHORT nCnt = 0;
     const USHORT* pPtr = pWhichPairTable;
@@ -367,7 +367,9 @@ SfxItemSet::SfxItemSet( const SfxItemSet& rASet ):
             *ppDst = &_pPool->Put( **ppSrc );
 
     // dann noch die Which Ranges kopieren
-    DBG_TRACE1("SfxItemSet: Ranges-CopyCount==%ul", ++nRangesCopyCount);
+    #if OSL_DEBUG_LEVEL > 1
+    OSL_TRACE("SfxItemSet: Ranges-CopyCount==%ul", ++nRangesCopyCount);
+    #endif
     std::ptrdiff_t cnt = pPtr - rASet._pWhichRanges+1;
     _pWhichRanges = new USHORT[ cnt ];
     memcpy( _pWhichRanges, rASet._pWhichRanges, sizeof( USHORT ) * cnt);
@@ -496,7 +498,7 @@ USHORT SfxItemSet::ClearItem( USHORT nWhich )
 
                         // #i32448#
                         // Take care of disabled items, too.
-                        if(!pItemToClear->nWhich)
+                        if(!pItemToClear->m_nWhich)
                         {
                             // item is disabled, delete it
                             delete pItemToClear;
@@ -778,7 +780,7 @@ void SfxItemSet::PutExtended
                             break;
 
                         default:
-                            DBG_ERROR( "invalid Argument for eDontCareAs" );
+                            OSL_FAIL( "invalid Argument for eDontCareAs" );
                     }
                 }
                 else
@@ -803,7 +805,7 @@ void SfxItemSet::PutExtended
                         break;
 
                     default:
-                        DBG_ERROR( "invalid Argument for eDefaultAs" );
+                        OSL_FAIL( "invalid Argument for eDefaultAs" );
                 }
             }
         pPtr += 2;
@@ -913,7 +915,7 @@ const SfxPoolItem* SfxItemSet::GetItem
             return pItem;
 
         // sonst Fehler melden
-        DBG_ERROR( "invalid argument type" );
+        OSL_FAIL( "invalid argument type" );
     }
 
     // kein Item gefunden oder falschen Typ gefunden
@@ -1438,7 +1440,7 @@ USHORT SfxItemSet::GetWhichByPos( USHORT nPos ) const
 SvStream &SfxItemSet::Store
 (
     SvStream&	rStream,		// Zielstream f"ur normale Items
-    FASTBOOL	bDirect 		// TRUE: Items direkt speicher, FALSE: Surrogate
+    bool	bDirect 		// TRUE: Items direkt speicher, FALSE: Surrogate
 )	const
 
 /*	[Beschreibung]
@@ -1505,7 +1507,7 @@ SvStream &SfxItemSet::Load
 (
     SvStream&			rStream,	//	Stream, aus dem geladen werden soll
 
-    FASTBOOL			bDirect,	/*	TRUE
+    bool			bDirect,	/*	TRUE
                                         Items werden direkt aus dem Stream
                                         gelesen, nicht "uber Surrogate
 
@@ -1979,73 +1981,6 @@ void SfxItemSet::DisableItem(USHORT nWhich)
 
 // -----------------------------------------------------------------------
 
-#if 0
-BOOL SfxAllItemSet::Remove(USHORT nWhich)
-{
-    DBG_CHKTHIS(SfxAllItemSet, 0);
-    USHORT *pPtr = _pWhichRanges;
-    USHORT nPos = 0;
-    while( *pPtr )
-    {
-        if( *pPtr <= nWhich && nWhich <= *(pPtr+1) )
-        {
-            USHORT *pTmp = pPtr;
-            USHORT nLeft = 0;
-            USHORT nRest = 0;
-            while(*++pTmp){
-                if( nLeft & 1 )
-                    nRest = *pTmp - *(pTmp-1) + 1;
-                ++nLeft;
-            }
-
-            // in diesem Bereich
-            nPos += nWhich - *pPtr;
-            nRest -= nWhich - *pPtr;
-            // 3,3
-            if(*pPtr == nWhich && *(pPtr+1) == nWhich) {
-                memmove(pPtr, pPtr + 2, nLeft * sizeof(USHORT));
-                nFree += 2;
-            }
-                // Anfang
-            else if(*pPtr == nWhich)
-                (*pPtr)++;
-                // Ende
-            else if(*(pPtr+1) == nWhich)
-                (*(pPtr+1))--;
-            else {
-                if(nPos + nRest + 2 > nFree) {
-                    USHORT nOf = pPtr - _pWhichRanges;
-                    _pWhichRanges = IncrSize(_pWhichRanges, nPos + nRest, nInitCount);
-                    nFree += nInitCount;
-                    pPtr = _pWhichRanges + nOf;
-                }
-                memmove(pPtr +2, pPtr, (nLeft+2) * sizeof(USHORT));
-                *++pPtr  = nWhich-1;
-                *++pPtr = nWhich+1;
-                nFree -= 2;
-            }
-            SfxPoolItem* pItem = *( _aItems + nPos );
-            if( pItem )
-            {
-                if(_pPool)
-                    _pPool->Remove(*pItem );
-                else
-                    delete pItem;
-                --_nCount;
-            }
-            memmove(_aItems + nPos +1, _aItems + nPos,
-                    sizeof(SfxPoolItem *) * (nRest - 1));
-            break; 			// dann beim Parent suchen
-        }
-        nPos += *(pPtr+1) - *pPtr + 1;
-        pPtr += 2;
-    }
-    return *pPtr? TRUE: FALSE;
-}
-#endif
-
-// -----------------------------------------------------------------------
-
 SfxItemSet *SfxAllItemSet::Clone(BOOL bItems, SfxItemPool *pToPool ) const
 {
     DBG_CHKTHIS(SfxItemSet, DbgCheckItemSet);
