@@ -96,8 +96,8 @@ using namespace ::com::sun::star;
 /*N*/ 	Clear(); // Containerinhalt loeschen!
 /*N*/ }
 
-/*N*/ void SdrObjList::operator=(const SdrObjList& rSrcList)
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SdrObjList::operator=(const SdrObjList& /*rSrcList*/)
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 /*N*/ void SdrObjList::CopyObjects(const SdrObjList& rSrcList)
@@ -124,7 +124,7 @@ using namespace ::com::sun::star;
 /*N*/ 	// Aehnliche Implementation an folgenden Stellen:
 /*N*/ 	//    void SdrObjList::CopyObjects(const SdrObjList& rSrcList)
 /*N*/ 	//    SdrModel* SdrExchangeView::GetMarkedObjModel() const
-/*N*/ 	//    FASTBOOL SdrExchangeView::Paste(const SdrModel& rMod,...)
+/*N*/ 	//    bool SdrExchangeView::Paste(const SdrModel& rMod,...)
 /*N*/ 	//    void SdrEditView::CopyMarked()
 /*N*/ 	if (nCloneErrCnt==0) {
 /*N*/ 		for (no=0; no<nAnz; no++) {
@@ -145,7 +145,7 @@ using namespace ::com::sun::star;
 /*?*/ 							if (pDstNode1!=NULL) { // Sonst grober Fehler!
 /*?*/ 								pDstEdge->ConnectToNode(TRUE,pDstNode1);
 /*?*/ 							} else {
-/*?*/ 								DBG_ERROR("SdrObjList::operator=(): pDstNode1==NULL!");
+/*?*/ 								OSL_FAIL("SdrObjList::operator=(): pDstNode1==NULL!");
 /*?*/ 							}
 /*?*/ 						}
 /*?*/ 						if (pSrcNode2!=NULL) {
@@ -154,11 +154,11 @@ using namespace ::com::sun::star;
 /*?*/ 							if (pDstNode2!=NULL) { // Node war sonst wohl nicht markiert
 /*?*/ 								pDstEdge->ConnectToNode(FALSE,pDstNode2);
 /*?*/ 							} else {
-/*?*/ 								DBG_ERROR("SdrObjList::operator=(): pDstNode2==NULL!");
+/*?*/ 								OSL_FAIL("SdrObjList::operator=(): pDstNode2==NULL!");
 /*?*/ 							}
 /*?*/ 						}
 /*?*/ 					} else {
-/*?*/ 						DBG_ERROR("SdrObjList::operator=(): pDstEdge==NULL!");
+/*?*/ 						OSL_FAIL("SdrObjList::operator=(): pDstEdge==NULL!");
 /*?*/ 					}
 /*?*/ 				}
 /*N*/ 			}
@@ -180,7 +180,7 @@ using namespace ::com::sun::star;
 /*?*/ 
 /*?*/ 		aStr += " Objektverbindungen werden nicht mitkopiert.";
 /*?*/ 
-/*?*/ 		DBG_ERROR(aStr.GetBuffer());
+/*?*/ 		OSL_FAIL(aStr.GetBuffer());
 /*?*/ #endif
 /*N*/ 	}
 /*N*/ }
@@ -280,7 +280,7 @@ using namespace ::com::sun::star;
 /*N*/ 	if (pUpList!=NULL) pUpList->SetRectsDirty();
 /*N*/ }
 
-/*N*/ void SdrObjList::NbcInsertObject(SdrObject* pObj, ULONG nPos, const SdrInsertReason* pReason)
+/*N*/ void SdrObjList::NbcInsertObject(SdrObject* pObj, ULONG nPos, const SdrInsertReason* /*pReason*/)
 /*N*/ {
 /*N*/ 	DBG_ASSERT(pObj!=NULL,"SdrObjList::NbcInsertObject(NULL)");
 /*N*/ 	if (pObj!=NULL) {
@@ -348,8 +348,8 @@ using namespace ::com::sun::star;
 /*N*/ 	}
 /*N*/ }
 
-/*N*/ SdrObject* SdrObjList::NbcRemoveObject(ULONG nObjNum)
-/*N*/ {DBG_BF_ASSERT(0, "STRIP");return NULL; //STRIP001 
+/*N*/ SdrObject* SdrObjList::NbcRemoveObject(ULONG /*nObjNum*/)
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");return NULL;
 /*N*/ }
 
 /*N*/ SdrObject* SdrObjList::RemoveObject(ULONG nObjNum)
@@ -445,10 +445,6 @@ using namespace ::com::sun::star;
 /*N*/ 	DBG_ASSERT(pObj!=NULL,"SdrObjList::SetObjectOrdNum: Object nicht gefunden");
 /*N*/ 	if (pObj!=NULL) {
 /*N*/ 		DBG_ASSERT(pObj->IsInserted(),"SdrObjList::SetObjectOrdNum: ZObjekt hat keinen Inserted-Status");
-        /*if (pModel!=NULL) {
-            // Hier muss ein anderer Broadcast her!
-            if (pObj->GetPage()!=NULL) pModel->Broadcast(SdrHint(*pObj));
-        }*/
 /*N*/ 		aList.Remove(nOldObjNum);
 /*N*/ 		aList.Insert(pObj,nNewObjNum);
 /*N*/ 		pObj->SetOrdNum(nNewObjNum);
@@ -480,7 +476,7 @@ using namespace ::com::sun::star;
 /*N*/ 	return aOutRect;
 /*N*/ }
 
-/*N*/ FASTBOOL SdrObjList::Paint(ExtOutputDevice& rXOut, const SdrPaintInfoRec& rInfoRec, FASTBOOL bRestoreColors) const
+/*N*/ bool SdrObjList::Paint(ExtOutputDevice& rXOut, const SdrPaintInfoRec& rInfoRec, bool bRestoreColors) const
 /*N*/ {
 /*N*/ 	BOOL bOk(TRUE);
 /*N*/ 	BOOL bWasNotActive = rInfoRec.bNotActive;
@@ -535,20 +531,20 @@ using namespace ::com::sun::star;
 /*N*/ 	return bOk;
 /*N*/ }
 
-/*N*/ FASTBOOL SdrObjList::Paint(ExtOutputDevice& rXOut, const SdrPaintInfoRec& rInfoRec, FASTBOOL bRestoreColors, USHORT nImpMode) const
+/*N*/ bool SdrObjList::Paint(ExtOutputDevice& rXOut, const SdrPaintInfoRec& rInfoRec, bool bRestoreColors, USHORT nImpMode) const
 /*N*/ {
-/*N*/ 	FASTBOOL bOk=TRUE;
-/*N*/ 	FASTBOOL bBrk=FALSE;
+/*N*/ 	bool bOk=TRUE;
+/*N*/ 	bool bBrk=FALSE;
 /*N*/ 	ULONG nObjAnz=GetObjCount();
 /*N*/ 	if (nObjAnz==0) return TRUE;
 /*N*/ 	USHORT nEvent=rInfoRec.nBrkEvent;
 /*N*/ 	const SetOfByte* pVisiLayer=&rInfoRec.aPaintLayer;
-/*N*/ 	FASTBOOL bPrinter=rInfoRec.bPrinter;
+/*N*/ 	bool bPrinter=rInfoRec.bPrinter;
 /*N*/ 	OutputDevice* pOut=rXOut.GetOutDev();
 /*N*/ 	Rectangle aCheckRect(rInfoRec.aCheckRect);
-/*N*/ 	FASTBOOL bDrawAll=aCheckRect.IsEmpty();
+/*N*/ 	bool bDrawAll=aCheckRect.IsEmpty();
 /*N*/ 	ImpSdrHdcMerk aHDCMerk(*pOut,SDRHDC_SAVEPENANDBRUSHANDFONT,bRestoreColors);
-/*N*/ 	FASTBOOL bColorsDirty=FALSE;
+/*N*/ 	bool bColorsDirty=FALSE;
 /*N*/ 	if (bDrawAll || aCheckRect.IsOver(GetAllObjBoundRect())) {
 /*N*/ 		Application* pAppPtr=NULL;
 /*N*/ 		if (nEvent!=0) pAppPtr=GetpApp();
@@ -597,12 +593,12 @@ using namespace ::com::sun::star;
 /*N*/ 		for (USHORT nCycle = 1; nCycle <= nPaintCycles; nCycle++)
 /*N*/ 		{
 /*N*/ 			USHORT		nPaintImpMode = nImpMode;
-/*N*/ 			FASTBOOL	bNormal = ( nPaintImpMode == IMP_PAGEPAINT_NORMAL );
-/*N*/ 			FASTBOOL	bCachePrepare = ( nPaintImpMode == IMP_PAGEPAINT_PREPARE_CACHE );
-/*N*/ 			FASTBOOL	bBGCachePrepare = ( nPaintImpMode == IMP_PAGEPAINT_PREPARE_BG_CACHE );
-/*N*/ 			FASTBOOL	bCachePaint = ( nPaintImpMode == IMP_PAGEPAINT_PAINT_CACHE );
-/*N*/ 			FASTBOOL	bBGCachePaint = ( nPaintImpMode == IMP_PAGEPAINT_PAINT_BG_CACHE );
-/*N*/ 			FASTBOOL	bPaintFlag = ( bNormal || bCachePrepare || bBGCachePrepare );
+/*N*/ 			bool	bNormal = ( nPaintImpMode == IMP_PAGEPAINT_NORMAL );
+/*N*/ 			bool	bCachePrepare = ( nPaintImpMode == IMP_PAGEPAINT_PREPARE_CACHE );
+/*N*/ 			bool	bBGCachePrepare = ( nPaintImpMode == IMP_PAGEPAINT_PREPARE_BG_CACHE );
+/*N*/ 			bool	bCachePaint = ( nPaintImpMode == IMP_PAGEPAINT_PAINT_CACHE );
+/*N*/ 			bool	bBGCachePaint = ( nPaintImpMode == IMP_PAGEPAINT_PAINT_BG_CACHE );
+/*N*/ 			bool	bPaintFlag = ( bNormal || bCachePrepare || bBGCachePrepare );
 /*N*/ 
 /*N*/ 			if( nCycle == 2 )
 /*N*/ 			{
@@ -687,7 +683,7 @@ using namespace ::com::sun::star;
 /*N*/ 						if( bPaintFlag )
 /*N*/ 						{
 /*N*/ 							if( pObj->IsNeedColorRestore() )
-/*?*/ 							{DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*?*/ 							{DBG_BF_ASSERT(0, "STRIP");
 /*N*/ 							}
 /*N*/ 							else
 /*N*/ 								bColorsDirty=TRUE; // andere aendern die Farben
@@ -701,53 +697,6 @@ using namespace ::com::sun::star;
 /*N*/ 							else
 /*N*/ 							{
 /*N*/ 								bOk=pObj->Paint(rXOut,rInfoRec);
-
-//////////////////////////////////////////////////////////////////////////////
-//
-//	Vector2D aTRScale;
-//	double fTRShear;
-//	double fTRRotate;
-//	Vector2D aTRTranslate;
-//	Matrix3D aOrigMat;
-//	XPolyPolygon aTRPolyPolygon;
-//
-//	BOOL bIsPath = pObj->TRGetBaseGeometry(aOrigMat, aTRPolyPolygon);
-//	aOrigMat.DecomposeAndCorrect(aTRScale, fTRShear, fTRRotate, aTRTranslate);
-//	Vector2D aVectorTranslate;
-//	aVectorTranslate.X() = FRound(aTRTranslate.X());
-//	aVectorTranslate.Y() = FRound(aTRTranslate.Y());
-//
-//	Point aPoint(aVectorTranslate.X(), aVectorTranslate.Y());
-//	Rectangle aTRBaseRect(
-//		aPoint,
-//		Size(FRound(aTRScale.X()), FRound(aTRScale.Y())));
-//
-//	Color aLineColorMerk(rXOut.GetOutDev()->GetLineColor());
-//	Color aFillColorMerk(rXOut.GetOutDev()->GetFillColor());
-//	rXOut.GetOutDev()->SetFillColor();
-//
-//	rXOut.GetOutDev()->SetLineColor(COL_BLACK);
-//	rXOut.GetOutDev()->DrawRect(aTRBaseRect);
-//
-//	if(bIsPath)
-//	{
-//		rXOut.GetOutDev()->SetLineColor(COL_LIGHTRED);
-//		XPolyPolygon aTRPoPo(aTRPolyPolygon);
-//		aTRPoPo.Move(aTRBaseRect.Left(), aTRBaseRect.Top());
-//		sal_uInt16 nCount(aTRPoPo.Count());
-//		for(sal_uInt16 a(0); a < nCount; a++)
-//			rXOut.GetOutDev()->DrawPolygon(XOutCreatePolygon(aTRPoPo[a], rXOut.GetOutDev()));
-//	}
-//
-//	rXOut.GetOutDev()->SetLineColor(aLineColorMerk);
-//	rXOut.GetOutDev()->SetFillColor(aFillColorMerk);
-//
-//	static BOOL bDoTestSetAllGeometry(FALSE);
-//	if(bDoTestSetAllGeometry)
-//		pObj->TRSetBaseGeometry(aOrigMat, aTRPolyPolygon);
-//
-//
-//////////////////////////////////////////////////////////////////////////////
 /*N*/ 							}
 /*N*/ 
 /*N*/ 							// nach dem ersten Objekt bei reinem Hintergrundcache
@@ -864,13 +813,13 @@ using namespace ::com::sun::star;
 
 /*N*/ void SdrObjList::Save(SvStream& rOut) const
 /*N*/ {
-/*N*/ 	FASTBOOL bNotPersist=pPage!=NULL && pPage->IsObjectsNotPersistent();
-/*N*/ 	FASTBOOL bNoOLE=pModel!=NULL && pModel->IsStreamingSdrModel();
+/*N*/ 	bool bNotPersist=pPage!=NULL && pPage->IsObjectsNotPersistent();
+/*N*/ 	bool bNoOLE=pModel!=NULL && pModel->IsStreamingSdrModel();
 /*N*/ 	if (!bNotPersist) {
 /*N*/ 		SdrObjListIter aIter(*this,IM_FLAT);
 /*N*/ 		while (aIter.IsMore()) {
 /*N*/ 			SdrObject* pObj=aIter.Next();
-/*N*/ 			FASTBOOL bThisObjNot=pObj->IsNotPersistent();
+/*N*/ 			bool bThisObjNot=pObj->IsNotPersistent();
 /*N*/ 			if (!bThisObjNot && bNoOLE && pObj->ISA(SdrOle2Obj)) {
 /*N*/ 				bThisObjNot=TRUE;
 /*N*/ 			}
@@ -889,7 +838,7 @@ using namespace ::com::sun::star;
 /*N*/ 		return;
 /*N*/ 
 /*N*/ 	SdrInsertReason aReason(SDRREASON_STREAMING);
-/*N*/ 	FASTBOOL		bEnde=FALSE;
+/*N*/ 	bool		bEnde=FALSE;
 /*N*/ 
 /*N*/ 	while( rIn.GetError()==0 && !rIn.IsEof() && !bEnde )
 /*N*/ 	{
@@ -999,7 +948,7 @@ using namespace ::com::sun::star;
 /*?*/ 				aStr += ", BlockSize: ";
 /*?*/ 				aStr += ByteString::CreateFromInt32( aHead.GetBlockSize() );
 /*?*/ 
-/*?*/ 				DBG_ERROR(aStr.GetBuffer());
+/*?*/ 				OSL_FAIL(aStr.GetBuffer());
 /*?*/ #endif
 /*?*/ 
 /*?*/ #ifdef SVX_LIGHT
@@ -1033,11 +982,11 @@ using namespace ::com::sun::star;
 /*N*/ }
 
 /*?*/ void SdrObjList::FlattenGroups()
-/*?*/ {DBG_BF_ASSERT(0, "STRIP");//STRIP001 
+/*?*/ {DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
-/*?*/ void SdrObjList::UnGroupObj( ULONG nObjNum )
-/*?*/ {DBG_BF_ASSERT(0, "STRIP");//STRIP001 
+/*?*/ void SdrObjList::UnGroupObj( ULONG /*nObjNum*/ )
+/*?*/ {DBG_BF_ASSERT(0, "STRIP");
 /*?*/ }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -1100,14 +1049,14 @@ using namespace ::com::sun::star;
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /*N*/ void SdrPageGridFrameList::Clear()
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /*N*/ TYPEINIT1(SdrPage,SdrObjList);
 
-/*N*/ SdrPage::SdrPage(SdrModel& rNewModel, FASTBOOL bMasterPage):
+/*N*/ SdrPage::SdrPage(SdrModel& rNewModel, bool bMasterPage):
 /*N*/ 	SdrObjList(&rNewModel,this),
 /*N*/ 	pBackgroundObj( NULL )
 /*N*/ {
@@ -1142,10 +1091,6 @@ using namespace ::com::sun::star;
 /*N*/ 	delete pLayerAdmin;
 /*N*/ }
 
-
-
-
-
 /*N*/ void SdrPage::SetSize(const Size& aSiz)
 /*N*/ {
 /*N*/ 	nWdt=aSiz.Width();
@@ -1164,8 +1109,8 @@ using namespace ::com::sun::star;
 /*N*/ 	return nWdt;
 /*N*/ }
 
-/*N*/ void SdrPage::SetOrientation(Orientation eOri)
-/*N*/ {DBG_BF_ASSERT(0, "STRIP"); //STRIP001 
+/*N*/ void SdrPage::SetOrientation(Orientation /*eOri*/)
+/*N*/ {DBG_BF_ASSERT(0, "STRIP");
 /*N*/ }
 
 
@@ -1232,13 +1177,6 @@ using namespace ::com::sun::star;
 /*N*/ 	return nBordLwr;
 /*N*/ }
 
-// #i3694#
-// This GetOffset() method is not needed anymore, it even leads to errors.
-//Point SdrPage::GetOffset() const
-//{
-//	return Point();
-//}
-
 /*N*/ void SdrPage::SetModel(SdrModel* pNewModel)
 /*N*/ {
 /*N*/ 	SdrModel* pOldModel=pModel;
@@ -1368,15 +1306,6 @@ using namespace ::com::sun::star;
 /*N*/ 	}
 /*N*/ }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
-
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
-
-////////////////////////////////////////////////////////////////////////////////////////////////////
-
-
 ////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /*N*/ void SdrPage::ReadData(const SdrIOHeader& rHead, SvStream& rIn)
@@ -1417,7 +1346,7 @@ using namespace ::com::sun::star;
 /*N*/ 		}
 /*N*/ 	}
 /*N*/ 
-/*N*/ 	FASTBOOL bEnde=FALSE;
+/*N*/ 	bool bEnde=FALSE;
 /*N*/ 	while (rIn.GetError()==0 && !rIn.IsEof() && !bEnde) {
 /*N*/ 		SdrIOHeaderLookAhead aHead(rIn);   // Layerdefinitionen lesen
 /*N*/ 		if (aHead.IsID(SdrIOLayrID)) {
@@ -1565,7 +1494,7 @@ using namespace ::com::sun::star;
 /*N*/ 	delete pBackgroundObj, pBackgroundObj = pObj;
 /*N*/ }
 
-/*N*/ void SdrPage::SetInserted( FASTBOOL bIns )
+/*N*/ void SdrPage::SetInserted( bool bIns )
 /*N*/ {
 /*N*/ 	if( bInserted != bIns )
 /*N*/ 	{
@@ -1621,7 +1550,7 @@ using namespace ::com::sun::star;
 
 
 /** returns an averaged background color of this page */
-/*N*/ Color SdrPage::GetBackgroundColor( SdrPageView* pView ) const
+/*N*/ Color SdrPage::GetBackgroundColor( SdrPageView* /*pView*/ ) const
 /*N*/ {DBG_BF_ASSERT(0, "STRIP"); Color aColor; return aColor; 
 /*N*/ }
 
