@@ -27,35 +27,21 @@
  ************************************************************************/
 
 #include <bf_migratefilter.hxx>
-
 #include <com/sun/star/util/XCloseable.hpp>
-
-
-
+#include <com/sun/star/document/XExporter.hpp>
 #include <com/sun/star/xml/sax/XParser.hpp>
-
-#include <com/sun/star/frame/XStorable.hpp>
-
 #include <com/sun/star/frame/XLoadable.hpp>
-
+#include <com/sun/star/frame/XStorable.hpp>
 #include <com/sun/star/io/XSeekable.hpp>
-
-
 #include <legacysmgr/legacy_binfilters_smgr.hxx>
-
 #include <com/sun/star/task/XInteractionHandler.hpp>
-
 #include <bf_sfx2/app.hxx>
-
 #include <bf_sfx2/fcontnr.hxx>
-
 #include <bf_sfx2/docfac.hxx>
-
 #include <bf_so3/staticbaseurl.hxx>
 
 namespace binfilter {
 
-using namespace rtl;
 using namespace com::sun::star;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -67,6 +53,7 @@ using namespace com::sun::star::xml::sax;
 using namespace com::sun::star::frame;
 using namespace com::sun::star::task;
 using namespace com::sun::star::util;
+using ::rtl::OUString;
 
 const OUString sServiceNameTextDocument(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.TextDocument"));
 const OUString sServiceNameGlobalDocument(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.GlobalDocument"));
@@ -262,12 +249,12 @@ sal_Bool bf_MigrateFilter::importImpl(const Sequence< ::com::sun::star::beans::P
             }
             catch(IOException& /*e*/)
             {
-                OSL_ENSURE(sal_False, "IO exception.");
+                OSL_FAIL("IO exception.");
                 bRetval = sal_False;
             }
             catch(IllegalArgumentException& /*e*/)
             {
-                OSL_ENSURE(sal_False, "uno url invalid");
+                OSL_FAIL("uno url invalid");
                 bRetval = sal_False;
             }
         }
@@ -292,47 +279,37 @@ sal_Bool bf_MigrateFilter::importImpl(const Sequence< ::com::sun::star::beans::P
             || rStrippedServiceInfo->supportsService(sServiceNameWebDocument) ) && pFilter->UsesStorage() )
         {
             // writer document
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Writer)");
+            aFilterName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StarOffice XML (Writer)" ));
         }
         else if(rStrippedServiceInfo->supportsService(sServiceNamePresentationDocument))
         {
             // presentation: Ask BEFORE draw since presentation supports draw, too
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Impress)");
+            aFilterName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StarOffice XML (Impress)" ));
         }
         else if(rStrippedServiceInfo->supportsService(sServiceNameDrawingDocument))
         {
             // drawing document
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Draw)");
+            aFilterName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StarOffice XML (Draw)" ));
         }
         else if(rStrippedServiceInfo->supportsService(sServiceNameSpreadsheetDocument))
         {
             // calc document
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Calc)");
+            aFilterName = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StarOffice XML (Calc)" ));
         }
-/*
-        else if(rStrippedServiceInfo->supportsService(sServiceNameChartDocument))
-        {
-            // chart document
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Chart)");
-        }
-        else if(rStrippedServiceInfo->supportsService(sServiceNameFormulaProperties))
-        {
-            // formula document
-            aFilterName = ::rtl::OUString::createFromAscii("StarOffice XML (Math)");
-        }
-*/
-        if ( aFilterName.getLength() && !bInserting )
+
+        if ( aFilterName.getLength() && !bInserting &&  pFilter->GetFilterFlags() &  SFX_FILTER_EXPORT)
         {
+            // we do not enter here if the filter has not EXPORT capability, since this implies no write
             uno::Reference < io::XStream > xTempFile(
-                mxMSF->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.io.TempFile" ) ),
+                mxMSF->createInstance( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.io.TempFile" )) ),
                     uno::UNO_QUERY_THROW );
             uno::Reference < frame::XStorable > xDoc( rStrippedDocument, uno::UNO_QUERY );
             uno::Sequence < beans::PropertyValue > args(2);
-            args[0].Name = ::rtl::OUString::createFromAscii("OutputStream");
+            args[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "OutputStream" ));
             args[0].Value <<= xTempFile->getOutputStream();
-            args[1].Name = ::rtl::OUString::createFromAscii("FilterName");
+            args[1].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterName" ));
             args[1].Value <<= aFilterName;
-            xDoc->storeToURL( ::rtl::OUString::createFromAscii("private:stream/"), args );
+            xDoc->storeToURL( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "private:stream/" )), args );
             xTempFile->getOutputStream()->closeOutput();
 
             Sequence< Any > aArgs( 2 );
@@ -458,325 +435,6 @@ sal_Bool bf_MigrateFilter::importImpl(const Sequence< ::com::sun::star::beans::P
     return bRetval;
 }
 
-sal_Bool bf_MigrateFilter::exportImpl(const Sequence< ::com::sun::star::beans::PropertyValue >& aDescriptor)
-    throw (RuntimeException)
-{
-    sal_Int32 nLength(aDescriptor.getLength());
-    const PropertyValue* pValue = aDescriptor.getConstArray();
-
-    Reference < XOutputStream > xOutputStream;
-    Reference< XMultiServiceFactory > rStrippedMSF;
-    Reference< XCloseable > rStrippedDocument;
-    Reference < XDocumentHandler > xStrippedDocumentHandler;
-    Reference < XExporter > xLocalExporter;
-    Reference< XInteractionHandler > xInteractionHandler;
-
-    OUString sFilterName;
-    OUString sXMLImportService;
-    OUString sXMLExportService;
-    OUString sStrippedDocumentType;
-
-    sal_Bool bRetval(sal_True);
-    sal_Bool bStrippedDocumentCreated(sal_False);
-
-    for(sal_Int32 a(0); a < nLength; a++)
-    {
-        OUString sName(pValue[a].Name);
-
-        if(pValue[a].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("OutputStream")))
-            pValue[a].Value >>= xOutputStream;
-
-        else if(pValue[a].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("FilterName")))
-            pValue[a].Value >>= sFilterName;
-
-        else if(pValue[a].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("InteractionHandler")))
-            pValue[a].Value >>= xInteractionHandler;
-    }
-
-    // only the binary part should touch URLs; make sure that no BaseURL is passed to the exporter also
-    ::binfilter::StaticBaseUrl::SetBaseURL( String() );
-
-    if(bRetval)
-    {
-        // test for necessary inputs
-        if(!xOutputStream.is())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-        else if(!sFilterName.getLength())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-    }
-
-    if(bRetval)
-    {
-        // try to get connection to Stripped office
-        sal_Bool bGotLegacyServiceManager = getContactToLegacyProcessServiceFactory();
-
-        if(!bGotLegacyServiceManager)
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-    }
-
-    if(bRetval)
-    {
-        // get contact to Stripped ServiceFactory
-        rStrippedMSF = Reference< XMultiServiceFactory >::query(mxLegServFact);
-
-        if(!rStrippedMSF.is())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-    }
-
-    if(bRetval)
-    {
-        // what type of document am I?
-        Reference < XServiceInfo > rLocalServiceInfo(mxDoc, UNO_QUERY);
-
-        if(rLocalServiceInfo.is())
-        {
-            if(rLocalServiceInfo->supportsService(sServiceNameTextDocument)
-                || rLocalServiceInfo->supportsService(sServiceNameGlobalDocument)
-                || rLocalServiceInfo->supportsService(sServiceNameWebDocument))
-            {
-                // writer document
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Writer.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Writer.XMLExporter"));
-
-                if(rLocalServiceInfo->supportsService(sServiceNameGlobalDocument))
-                {
-                    sStrippedDocumentType = sServiceNameGlobalDocument;
-                }
-                else if(rLocalServiceInfo->supportsService(sServiceNameWebDocument))
-                {
-                    sStrippedDocumentType = sServiceNameWebDocument;
-                }
-                else
-                {
-                    sStrippedDocumentType = sServiceNameTextDocument;
-                }
-            }
-            else if(rLocalServiceInfo->supportsService(sServiceNamePresentationDocument))
-            {
-                // presentation: Ask BEFORE draw since presentation supports draw, too
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Impress.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Impress.XMLExporter"));
-                sStrippedDocumentType = sServiceNamePresentationDocument;
-            }
-            else if(rLocalServiceInfo->supportsService(sServiceNameDrawingDocument))
-            {
-                // drawing document
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Draw.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Draw.XMLExporter"));
-                sStrippedDocumentType = sServiceNameDrawingDocument;
-            }
-            else if(rLocalServiceInfo->supportsService(sServiceNameSpreadsheetDocument))
-            {
-                // calc document
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Calc.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Calc.XMLExporter"));
-                sStrippedDocumentType = sServiceNameSpreadsheetDocument;
-            }
-            else if(rLocalServiceInfo->supportsService(sServiceNameChartDocument))
-            {
-                // chart document
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Chart.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Chart.XMLExporter"));
-                sStrippedDocumentType = sServiceNameChartDocument;
-            }
-            else if(rLocalServiceInfo->supportsService(sServiceNameFormulaProperties))
-            {
-                // formula document
-                sXMLImportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Math.XMLImporter"));
-                sXMLExportService = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.Math.XMLExporter"));
-                sStrippedDocumentType = sServiceNameFormulaProperties;
-            }
-            else
-            {
-                OSL_ASSERT(0);
-                bRetval = sal_False;
-            }
-        }
-        else
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-    }
-
-    if(bRetval)
-    {
-        // open an empty Stripped document
-        rStrippedDocument = Reference< XCloseable >::query(rStrippedMSF->createInstance(sStrippedDocumentType));
-
-        if(!rStrippedDocument.is())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-        else
-        {
-            // get XLoadable, call initNew()
-            Reference < XLoadable > xLoadable(rStrippedDocument, UNO_QUERY);
-
-            if(xLoadable.is())
-            {
-                // the new document needs to be initialized before usage
-                xLoadable->initNew();
-            }
-
-            bStrippedDocumentCreated = sal_True;
-        }
-    }
-
-    if(bRetval)
-    {
-        // try to get Stripped document handler
-        xStrippedDocumentHandler = Reference< XDocumentHandler >::query(rStrippedMSF->createInstance(sXMLImportService));
-
-        if(!xStrippedDocumentHandler.is())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-        else
-        {
-            // set target document at Stripped document handler
-            Reference < XImporter > xStrippedImporter(xStrippedDocumentHandler, UNO_QUERY);
-            xStrippedImporter->setTargetDocument( Reference < XComponent >( rStrippedDocument, UNO_QUERY ) );
-        }
-    }
-
-    if(bRetval)
-    {
-        // try to create local exporter, give Stripped document handler as target
-        Sequence < Any > aAnys(1);
-        aAnys[0] <<= xStrippedDocumentHandler;
-
-        xLocalExporter = Reference< XExporter >::query(mxMSF->createInstanceWithArguments(sXMLExportService, aAnys));
-
-        if(!xLocalExporter.is())
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-        else
-        {
-            // set source document to local document
-            xLocalExporter->setSourceDocument(mxDoc);
-        }
-    }
-
-    if(bRetval)
-    {
-        try
-        {
-            // lock target document controllers
-            Reference < com::sun::star::frame::XModel > xTargetDocumentModel(rStrippedDocument, UNO_QUERY);
-            sal_Bool bTargetDocumentModelWasNotLocked(sal_False);
-
-            if(xTargetDocumentModel.is() && !xTargetDocumentModel->hasControllersLocked())
-            {
-                bTargetDocumentModelWasNotLocked = sal_True;
-                xTargetDocumentModel->lockControllers();
-            }
-
-            // now start the data exchange (needs fix #98472#)
-            Reference < XFilter > xFilter(xLocalExporter, UNO_QUERY);
-            bRetval = xFilter->filter(aDescriptor);
-
-            if(xTargetDocumentModel.is() && bTargetDocumentModelWasNotLocked)
-            {
-                xTargetDocumentModel->unlockControllers();
-            }
-        }
-        catch(RuntimeException& /*e*/)
-        {
-            OSL_ENSURE(sal_False, "a local call was aborted");
-            bRetval = sal_False;
-        }
-    }
-
-    if(bRetval)
-    {
-        // save Stripped document now with given filter to given filename
-        Reference < XStorable > xStrippedStorable(rStrippedDocument, UNO_QUERY);
-
-        if(xStrippedStorable.is())
-        {
-            try
-            {
-                // is XSeekable?
-                Reference <XSeekable> xSeekable;
-                xSeekable = Reference<XSeekable>::query(xOutputStream);
-
-                Sequence < PropertyValue > seqPropValues(xInteractionHandler.is() ? 4 : 3);
-
-                seqPropValues[0].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("Overwrite"));
-                seqPropValues[0].Value <<= sal_True;
-
-                seqPropValues[1].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("FilterName"));
-                seqPropValues[1].Value <<= sFilterName;
-
-                seqPropValues[2].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("OutputStream"));
-                seqPropValues[2].Value <<= xOutputStream;
-
-                if(xInteractionHandler.is())
-                {
-                    seqPropValues[3].Name = OUString(RTL_CONSTASCII_USTRINGPARAM("InteractionHandler"));
-                    seqPropValues[3].Value <<= xInteractionHandler;
-                }
-
-                const OUString sUrlToReadFromXOutputStream(RTL_CONSTASCII_USTRINGPARAM("private:stream"));
-
-                // To make this run, in the stripped sfx2 (look for #ChangedstoreAsURL# in bf_sfx2) the decision
-                // for using a SFX_FILTER_STARONEFILTER needs to be removed. Else, the migrate filter will
-                // be called again recursively.
-                xStrippedStorable->storeToURL(
-                    sUrlToReadFromXOutputStream,
-                    seqPropValues
-                    );
-            }
-            catch(IOException& /*e*/)
-            {
-                OSL_ENSURE(sal_False, "IO exception.");
-                bRetval = sal_False;
-            }
-            catch(IllegalArgumentException& /*e*/)
-            {
-                OSL_ENSURE(sal_False, "uno url invalid");
-                bRetval = sal_False;
-            }
-        }
-        else
-        {
-            OSL_ASSERT(0);
-            bRetval = sal_False;
-        }
-    }
-
-    if(bStrippedDocumentCreated)
-    {
-        // close Stripped document again
-        try
-        {
-            rStrippedDocument->close(sal_True);
-        }
-        catch(Exception& /*e*/)
-        {
-        }
-    }
-
-    return bRetval;
-}
-
 sal_Bool SAL_CALL bf_MigrateFilter::filter(const Sequence< ::com::sun::star::beans::PropertyValue >& aDescriptor)
     throw (RuntimeException)
 {
@@ -788,7 +446,7 @@ sal_Bool SAL_CALL bf_MigrateFilter::filter(const Sequence< ::com::sun::star::bea
         Reference < XComponent > xWrapper( mxLegServFact->createInstance(
             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.office.OfficeWrapper" ))), UNO_QUERY );
 
-        bRetval = (FILTER_EXPORT == meType) ? exportImpl(aDescriptor) : importImpl(aDescriptor);
+        bRetval = importImpl(aDescriptor);
 
         xWrapper->dispose();
         xWrapper = 0;
@@ -802,19 +460,10 @@ void SAL_CALL bf_MigrateFilter::cancel()
 {
 }
 
-// XExporter
-void SAL_CALL bf_MigrateFilter::setSourceDocument(const Reference< ::com::sun::star::lang::XComponent >& xDoc)
-    throw (::com::sun::star::lang::IllegalArgumentException, RuntimeException)
-{
-    meType = FILTER_EXPORT;
-    mxDoc = xDoc;
-}
-
 // XImporter
 void SAL_CALL bf_MigrateFilter::setTargetDocument(const Reference< ::com::sun::star::lang::XComponent >& xDoc)
     throw (::com::sun::star::lang::IllegalArgumentException, RuntimeException)
 {
-    meType = FILTER_IMPORT;
     mxDoc = xDoc;
 }
 
@@ -846,29 +495,26 @@ OUString bf_MigrateFilter_getImplementationName()
     return OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.comp.office.BF_MigrateFilter"));
 }
 
-#define SERVICE_NAME1 "com.sun.star.document.ExportFilter"
+
 #define SERVICE_NAME2 "com.sun.star.document.ImportFilter"
 
 sal_Bool SAL_CALL bf_MigrateFilter_supportsService(const OUString& ServiceName)
     throw (RuntimeException)
 {
-    return ServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(SERVICE_NAME1)) ||
-           ServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(SERVICE_NAME2));
+    return ServiceName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(SERVICE_NAME2));
 }
 
 Sequence< OUString > SAL_CALL bf_MigrateFilter_getSupportedServiceNames()
     throw (RuntimeException)
 {
-    Sequence < OUString > aRet(2);
+    Sequence < OUString > aRet(1);
     OUString* pArray = aRet.getArray();
 
-    pArray[0] =  OUString(RTL_CONSTASCII_USTRINGPARAM(SERVICE_NAME1));
-    pArray[1] =  OUString(RTL_CONSTASCII_USTRINGPARAM(SERVICE_NAME2));
+    pArray[0] =  OUString(RTL_CONSTASCII_USTRINGPARAM(SERVICE_NAME2));
 
     return aRet;
 }
 
-#undef SERVICE_NAME1
 #undef SERVICE_NAME2
 
 Reference< XInterface > SAL_CALL bf_MigrateFilter_createInstance(const Reference< XMultiServiceFactory > & rSMgr)
@@ -904,7 +550,7 @@ Sequence< OUString > SAL_CALL bf_MigrateFilter::getSupportedServiceNames()
     return bf_MigrateFilter_getSupportedServiceNames();
 }
 
-// eof
+
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
