@@ -837,7 +837,7 @@ exec_javaldx (Args *args)
     rtl_uString_newFromAscii( &pApp, "file://" );
     rtl_uString_newConcat( &pApp, pApp, args->pAppPath );
     pTmp = NULL;
-    rtl_uString_newFromAscii( &pTmp, "/../ure/bin/javaldx" );
+    rtl_uString_newFromAscii( &pTmp, "/../basis-link/ure-link/bin/javaldx" );
     rtl_uString_newConcat( &pApp, pApp, pTmp );
     rtl_uString_release( pTmp );
 
