@@ -4,6 +4,7 @@
 #include "stdafx2.h"
 #include "so_activex.h"
 #include "SOComWindowPeer.h"
+#include <sal/macros.h>
 
 /////////////////////////////////////////////////////////////////////////////
 //
@@ -15,7 +16,7 @@ STDMETHODIMP SOComWindowPeer::InterfaceSupportsErrorInfo(REFIID riid)
         &IID_ISOComWindowPeer,
     };
 
-    for (int i=0;i<sizeof(arr)/sizeof(arr[0]);i++)
+    for (int i=0;i<SAL_N_ELEMENTS(arr);i++)
     {
 #if defined(_MSC_VER) && (_MSC_VER >= 1300)
         if (InlineIsEqualGUID(*arr[i],riid))
