@@ -247,27 +247,27 @@ namespace pcr
         ::std::vector< ::rtl::OUString > aSuperfluous;
         if ( m_pHelper.get() )
         {
-            aSuperfluous.push_back( PROPERTY_CONTROLSOURCE );
-            aSuperfluous.push_back( PROPERTY_EMPTY_IS_NULL );
-            aSuperfluous.push_back( PROPERTY_FILTERPROPOSAL );
-            aSuperfluous.push_back( PROPERTY_LISTSOURCETYPE );
-            aSuperfluous.push_back( PROPERTY_LISTSOURCE );
-            aSuperfluous.push_back( PROPERTY_BOUNDCOLUMN );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_CONTROLSOURCE) );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_EMPTY_IS_NULL) );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_FILTERPROPOSAL) );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_LISTSOURCETYPE) );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_LISTSOURCE) );
+            aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_BOUNDCOLUMN) );
 
             bool bAllowBinding = m_pHelper->canBindToAnyDataType();
 
             if ( bAllowBinding )
             {
-                aSuperfluous.push_back( PROPERTY_MAXTEXTLEN );
-                aSuperfluous.push_back( PROPERTY_VALUEMIN );
-                aSuperfluous.push_back( PROPERTY_VALUEMAX );
-                aSuperfluous.push_back( PROPERTY_DECIMAL_ACCURACY );
-                aSuperfluous.push_back( PROPERTY_TIMEMIN );
-                aSuperfluous.push_back( PROPERTY_TIMEMAX );
-                aSuperfluous.push_back( PROPERTY_DATEMIN );
-                aSuperfluous.push_back( PROPERTY_DATEMAX );
-                aSuperfluous.push_back( PROPERTY_EFFECTIVE_MIN );
-                aSuperfluous.push_back( PROPERTY_EFFECTIVE_MAX );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_MAXTEXTLEN) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_VALUEMIN) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_VALUEMAX) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_DECIMAL_ACCURACY) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_TIMEMIN) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_TIMEMAX) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_DATEMIN) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_DATEMAX) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_EFFECTIVE_MIN) );
+                aSuperfluous.push_back(  static_cast<const rtl::OUString&>(PROPERTY_EFFECTIVE_MAX) );
             }
         }
 
@@ -283,8 +283,8 @@ namespace pcr
         ::std::vector< ::rtl::OUString > aInterestedInActuations( 2 );
         if ( m_pHelper.get() )
         {
-            aInterestedInActuations.push_back( PROPERTY_XSD_DATA_TYPE );
-            aInterestedInActuations.push_back( PROPERTY_XML_DATA_MODEL );
+            aInterestedInActuations.push_back(  static_cast<const rtl::OUString&>(PROPERTY_XSD_DATA_TYPE) );
+            aInterestedInActuations.push_back(  static_cast<const rtl::OUString&>(PROPERTY_XML_DATA_MODEL) );
         }
         if ( aInterestedInActuations.empty() )
             return Sequence< ::rtl::OUString >();
