@@ -63,6 +63,8 @@
 #include <com/sun/star/embed/UseBackupException.hpp>
 #include <com/sun/star/embed/StorageFormats.hpp>
 #include <com/sun/star/beans/NamedValue.hpp>
+#include <com/sun/star/xml/crypto/DigestID.hpp>
+#include <com/sun/star/xml/crypto/CipherID.hpp>
 #include <cppuhelper/implbase1.hxx>
 #include <ContentInfo.hxx>
 #include <cppuhelper/typeprovider.hxx>
@@ -83,6 +85,7 @@
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/ofopxmlhelper.hxx>
 #include <comphelper/documentconstants.hxx>
+#include <comphelper/sequenceashashmap.hxx>
 
 using namespace std;
 using namespace osl;
@@ -181,10 +184,12 @@ class DummyInputStream : public ::cppu::WeakImplHelper1< XInputStream >
 
 ZipPackage::ZipPackage (const uno::Reference < XMultiServiceFactory > &xNewFactory)
 : m_aMutexHolder( new SotMutexHolder )
+, m_nStartKeyGenerationID( xml::crypto::DigestID::SHA1 )
+, m_nChecksumDigestID( xml::crypto::DigestID::SHA1_1K )
+, m_nCommonEncryptionID( xml::crypto::CipherID::BLOWFISH_CFB_8 )
 , m_bHasEncryptedEntries ( sal_False )
 , m_bHasNonEncryptedEntries ( sal_False )
 , m_bInconsistent ( sal_False )
-, m_bUseManifest ( sal_True )
 , m_bForceRecovery ( sal_False )
 , m_bMediaTypeFallbackUsed ( sal_False )
 , m_nFormat( embed::StorageFormats::PACKAGE ) // package is the default format
@@ -224,6 +229,7 @@ void ZipPackage::parseManifest()
     if ( m_nFormat == embed::StorageFormats::PACKAGE )
     {
         sal_Bool bManifestParsed = sal_False;
+        bool bDifferentStartKeyAlgorithm = false;
         const OUString sMeta ( RTL_CONSTASCII_USTRINGPARAM ( "META-INF" ) );
         if ( m_xRootFolder->hasByName( sMeta ) )
         {
@@ -253,6 +259,10 @@ void ZipPackage::parseManifest()
                             const OUString sPropIterationCount ( RTL_CONSTASCII_USTRINGPARAM ( "IterationCount" ) );
                             const OUString sPropSize ( RTL_CONSTASCII_USTRINGPARAM ( "Size" ) );
                             const OUString sPropDigest ( RTL_CONSTASCII_USTRINGPARAM ( "Digest" ) );
+                            const OUString sPropDerivedKeySize ( RTL_CONSTASCII_USTRINGPARAM ( "DerivedKeySize" ) );
+                            const OUString sPropDigestAlgorithm ( RTL_CONSTASCII_USTRINGPARAM ( "DigestAlgorithm" ) );
+                            const OUString sPropEncryptionAlgorithm ( RTL_CONSTASCII_USTRINGPARAM ( "EncryptionAlgorithm" ) );
+                            const OUString sPropStartKeyAlgorithm ( RTL_CONSTASCII_USTRINGPARAM ( "StartKeyAlgorithm" ) );
                             
                             Sequence < Sequence < PropertyValue > > aManifestSequence = xReader->readManifestSequence ( xSink->getInputStream() );
                             sal_Int32 nLength = aManifestSequence.getLength();
@@ -264,7 +274,7 @@ void ZipPackage::parseManifest()
                             {
                                 OUString sPath, sMediaType, sVersion;
                                 const PropertyValue *pValue = pSequence->getConstArray();
-                                const Any *pSalt = NULL, *pVector = NULL, *pCount = NULL, *pSize = NULL, *pDigest = NULL;
+                                const Any *pSalt = NULL, *pVector = NULL, *pCount = NULL, *pSize = NULL, *pDigest = NULL, *pDigestAlg = NULL, *pEncryptionAlg = NULL, *pStartKeyAlg = NULL, *pDerivedKeySize = NULL;
                                 for (sal_Int32 j = 0, nNum = pSequence->getLength(); j < nNum; j++ )
                                 {
                                     if (pValue[j].Name.equals( sPropFullPath ) )
@@ -283,6 +293,14 @@ void ZipPackage::parseManifest()
                                         pSize = &(pValue[j].Value);
                                     else if (pValue[j].Name.equals( sPropDigest ) )
                                         pDigest = &(pValue[j].Value);
+                                    else if ( pValue[j].Name.equals( sPropDigestAlgorithm ) )
+                                        pDigestAlg = &( pValue[j].Value );
+                                    else if ( pValue[j].Name.equals( sPropEncryptionAlgorithm ) )
+                                        pEncryptionAlg = &( pValue[j].Value );
+                                    else if ( pValue[j].Name.equals( sPropStartKeyAlgorithm ) )
+                                        pStartKeyAlg = &( pValue[j].Value );
+                                    else if ( pValue[j].Name.equals( sPropDerivedKeySize ) )
+                                        pDerivedKeySize = &( pValue[j].Value );
                                 }
 
                                 if (sPath.getLength() && hasByHierarchicalName ( sPath ) )
@@ -303,10 +321,10 @@ void ZipPackage::parseManifest()
                                         pStream->SetMediaType ( sMediaType );
                                         pStream->SetFromManifest( sal_True );
             
-                                        if (pSalt && pVector && pCount && pSize)
+                                        if (pSalt && pVector && pCount && pSize && pDigest && pDigestAlg && pEncryptionAlg )
                                         {
-                                            Sequence < sal_uInt8 > aSequence;
-                                            sal_Int32 nCount = 0, nSize = 0;
+                                            Sequence < sal_Int8 > aSequence;
+                                            sal_Int32 nCount = 0, nSize = 0, nDigestAlg = 0, nEncryptionAlg = 0, nDerivedKeySize = 16, nStartKeyAlg = xml::crypto::DigestID::SHA1;
                                                                            pStream->SetToBeEncrypted ( sal_True );
             
                                             *pSalt >>= aSequence;
@@ -321,18 +339,34 @@ void ZipPackage::parseManifest()
                                             *pSize >>= nSize;
                                             pStream->setSize ( nSize );
             
-                                            if ( pDigest )
-                                            {
-                                                *pDigest >>= aSequence;
-                                                pStream->setDigest ( aSequence );
-                                            }
+                                            *pDigest >>= aSequence;
+                                            pStream->setDigest ( aSequence );
+
+                                            *pDigestAlg >>= nDigestAlg;
+                                            pStream->SetImportedChecksumAlgorithm( nDigestAlg );
+
+                                            *pEncryptionAlg >>= nEncryptionAlg;
+                                            pStream->SetImportedEncryptionAlgorithm( nEncryptionAlg );
+
+                                            if ( pDerivedKeySize )
+                                                *pDerivedKeySize >>= nDerivedKeySize;
+                                            pStream->SetImportedDerivedKeySize( nDerivedKeySize );
+
+                                            if ( pStartKeyAlg )
+                                                *pStartKeyAlg >>= nStartKeyAlg;
+                                            pStream->SetImportedStartKeyAlgorithm( nStartKeyAlg );
             
                                             pStream->SetToBeCompressed ( sal_True );
                                             pStream->SetToBeEncrypted ( sal_True );
                                             pStream->SetIsEncrypted ( sal_True );
                                             if ( !m_bHasEncryptedEntries
                                               && pStream->getName().equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "content.xml" ) ) ) )
+                                            {
                                                 m_bHasEncryptedEntries = sal_True;
+                                                m_nStartKeyGenerationID = nStartKeyAlg;
+                                                m_nChecksumDigestID = nDigestAlg;
+                                                m_nCommonEncryptionID = nEncryptionAlg;
+                                            }
                                         }
                                         else
                                             m_bHasNonEncryptedEntries = sal_True;
@@ -411,20 +445,30 @@ void ZipPackage::parseManifest()
 
         m_bInconsistent = m_pRootFolder->LookForUnexpectedODF12Streams( ::rtl::OUString() );
 
-        sal_Bool bODF12AndOlder = ( m_pRootFolder->GetVersion().compareTo( ODFVER_012_TEXT ) >= 0 );
-        if ( !m_bForceRecovery && bODF12AndOlder && m_bInconsistent )
+        sal_Bool bODF12AndNewer = ( m_pRootFolder->GetVersion().compareTo( ODFVER_012_TEXT ) >= 0 );
+        if ( !m_bForceRecovery && bODF12AndNewer )
         {
-            // this is an ODF1.2 document that contains streams not referred in the manifest.xml;
-            // in case of ODF1.2 documents without version in manifest.xml the property IsInconsistent
-            // should be checked later
-            throw ZipIOException(
-                ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "there are streams not referred in manifest.xml\n" ) ),
-                uno::Reference< uno::XInterface >() );
+            if ( m_bInconsistent )
+            {
+                // this is an ODF1.2 document that contains streams not referred in the manifest.xml;
+                // in case of ODF1.2 documents without version in manifest.xml the property IsInconsistent
+                // should be checked later
+                throw ZipIOException(
+                    ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "there are streams not referred in manifest.xml\n" ) ),
+                    uno::Reference< uno::XInterface >() );
+            }
+            else if ( bDifferentStartKeyAlgorithm )
+            {
+                // all the streams should be encrypted with the same StartKey in ODF1.2
+                // TODO/LATER: in future the exception should be thrown
+                OSL_ENSURE( false, "ODF1.2 contains different StartKey Algorithms" );
+                // throw ZipIOException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "More than one Start Key Generation algorithm is specified!" ) ), uno::Reference< uno::XInterface >() );
+            }
         }
 
         // in case it is a correct ODF1.2 document, the version must be set
         // and the META-INF folder is reserved for package format
-        if ( bODF12AndOlder )
+        if ( bODF12AndNewer )
             m_xRootFolder->removeByName( sMeta );
     }
 }
@@ -981,14 +1025,12 @@ void ZipPackage::WriteMimetypeMagicFile( ZipOutputStream& aZipOut )
 
     try
     {
-        rtl::Reference < EncryptionData > xEmpty;
-        aZipOut.putNextEntry( *pEntry, xEmpty );
+        aZipOut.putNextEntry( *pEntry, NULL );
         aZipOut.write( aType, 0, nBufferLength );
         aZipOut.closeEntry();
     }
     catch ( ::com::sun::star::io::IOException & r )
     {
-        OSL_FAIL( "Error adding mimetype to the ZipOutputStream" );
         throw WrappedTargetException( 
                 OUString( RTL_CONSTASCII_USTRINGPARAM ( OSL_LOG_PREFIX "Error adding mimetype to the ZipOutputStream!" ) ),
                 static_cast < OWeakObject * > ( this ), 
@@ -1015,19 +1057,20 @@ void ZipPackage::WriteManifest( ZipOutputStream& aZipOut, const vector< Sequence
 
         // Convert vector into a Sequence
         Sequence < Sequence < PropertyValue > > aManifestSequence ( aManList.size() );
-        Sequence < PropertyValue > * pSequence = aManifestSequence.getArray();
+        sal_Int32 nInd = 0;
         for (vector < Sequence < PropertyValue > >::const_iterator aIter = aManList.begin(), aEnd = aManList.end();
              aIter != aEnd;
-             ++aIter, ++pSequence)
-            *pSequence= (*aIter);
+             aIter++, nInd++ )
+        {
+            aManifestSequence[nInd] = ( *aIter );
+        }
         xWriter->writeManifestSequence ( xManOutStream,  aManifestSequence );
 
         sal_Int32 nBufferLength = static_cast < sal_Int32 > ( pBuffer->getPosition() );
         pBuffer->realloc( nBufferLength );
 
         // the manifest.xml is never encrypted - so pass an empty reference
-                rtl::Reference < EncryptionData > xEmpty;
-        aZipOut.putNextEntry( *pEntry, xEmpty );
+        aZipOut.putNextEntry( *pEntry, NULL );
         aZipOut.write( pBuffer->getSequence(), 0, nBufferLength );
         aZipOut.closeEntry();
     }
@@ -1089,8 +1132,7 @@ void ZipPackage::WriteContentTypes( ZipOutputStream& aZipOut, const vector< Sequ
     pBuffer->realloc( nBufferLength );
 
     // there is no encryption in this format currently
-            rtl::Reference < EncryptionData > xEmpty;
-    aZipOut.putNextEntry( *pEntry, xEmpty );
+    aZipOut.putNextEntry( *pEntry, NULL );
     aZipOut.write( pBuffer->getSequence(), 0, nBufferLength );
     aZipOut.closeEntry();
 }
@@ -1154,7 +1196,7 @@ uno::Reference< io::XInputStream > ZipPackage::writeTempFile()
     }
     
     // Hand it to the ZipOutputStream:
-    ZipOutputStream aZipOut ( xTempOut );
+    ZipOutputStream aZipOut ( m_xFactory, xTempOut );
     aZipOut.setMethod(DEFLATED);
     aZipOut.setLevel(DEFAULT_COMPRESSION);
 
@@ -1224,12 +1266,12 @@ uno::Reference< io::XInputStream > ZipPackage::writeTempFile()
     
         // call saveContents (it will recursively save sub-directories
         OUString aEmptyString;
-        m_pRootFolder->saveContents( aEmptyString, aManList, aZipOut, m_aEncryptionKey, aRandomPool );
+        m_pRootFolder->saveContents( aEmptyString, aManList, aZipOut, GetEncryptionKey(), aRandomPool );
     
         // Clean up random pool memory
         rtl_random_destroyPool ( aRandomPool );
 
-        if( m_bUseManifest && m_nFormat == embed::StorageFormats::PACKAGE )
+        if( m_nFormat == embed::StorageFormats::PACKAGE )
         {
             WriteManifest( aZipOut, aManList );
         }
@@ -1549,6 +1591,36 @@ void ZipPackage::DisconnectFromTargetAndThrowException_Impl( const uno::Referenc
                                     makeAny ( aException ) );
 }
 
+//--------------------------------------------------------
+const uno::Sequence< sal_Int8 > ZipPackage::GetEncryptionKey()
+{
+    uno::Sequence< sal_Int8 > aResult;
+
+    if ( m_aStorageEncryptionKeys.getLength() )
+    {
+        ::rtl::OUString aNameToFind;
+        if ( m_nStartKeyGenerationID == xml::crypto::DigestID::SHA256 )
+            aNameToFind = PACKAGE_ENCRYPTIONDATA_SHA256UTF8;
+        else if ( m_nStartKeyGenerationID == xml::crypto::DigestID::SHA1 )
+            aNameToFind = PACKAGE_ENCRYPTIONDATA_SHA1UTF8;
+        else
+            throw uno::RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "No expected key is provided!" ) ), uno::Reference< uno::XInterface >() );
+
+        for ( sal_Int32 nInd = 0; nInd < m_aStorageEncryptionKeys.getLength(); nInd++ )
+            if ( m_aStorageEncryptionKeys[nInd].Name.equals( aNameToFind ) )
+                m_aStorageEncryptionKeys[nInd].Value >>= aResult;
+
+        // empty keys are not allowed here
+        // so it is not important whether there is no key, or the key is empty, it is an error
+        if ( !aResult.getLength() )
+            throw uno::RuntimeException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "No expected key is provided!" ) ), uno::Reference< uno::XInterface >() );
+    }
+    else
+        aResult = m_aEncryptionKey;
+
+    return aResult;
+}
+
 sal_Bool SAL_CALL ZipPackage::hasPendingChanges(  ) 
         throw(RuntimeException)
 {
@@ -1639,20 +1711,91 @@ void SAL_CALL ZipPackage::setPropertyValue( const OUString& aPropertyName, const
     if ( m_nFormat != embed::StorageFormats::PACKAGE )
         throw UnknownPropertyException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
-    if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("HasEncryptedEntries") )
-      ||aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("HasNonEncryptedEntries") )
-      ||aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("IsInconsistent") )
-      ||aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("MediaTypeFallbackUsed") ) )
+    if ( aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( HAS_ENCRYPTED_ENTRIES_PROPERTY ) )
+      ||aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( HAS_NONENCRYPTED_ENTRIES_PROPERTY ) )
+      ||aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( IS_INCONSISTENT_PROPERTY ) )
+      ||aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( MEDIATYPE_FALLBACK_USED_PROPERTY ) ) )
         throw PropertyVetoException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
-    else if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("EncryptionKey") ) )
+    else if ( aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ENCRYPTION_KEY_PROPERTY ) ) )
     {
-        if (!( aValue >>= m_aEncryptionKey ) || m_aEncryptionKey.getLength() == 0 )
+        if (!( aValue >>= m_aEncryptionKey ) )
             throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >(), 2 );
+
+        m_aStorageEncryptionKeys.realloc( 0 );
     }
-    else if (aPropertyName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("UseManifest") ) )
+    else if (aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( STORAGE_ENCRYPTION_KEYS_PROPERTY ) ) )
     {
-        if (!( aValue >>= m_bUseManifest ) )
+        // this property is only necessary to support raw passwords in storage API;
+        // because of this support the storage has to operate with more than one key dependent on storage generation algorithm;
+        // when this support is removed, the storage will get only one key from outside
+        // TODO/LATER: Get rid of this property as well as of support of raw passwords in storages
+        uno::Sequence< beans::NamedValue > aKeys;
+        if ( !( aValue >>= aKeys ) || ( aKeys.getLength() && aKeys.getLength() < 2 ) )
             throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >(), 2 );
+
+        if ( aKeys.getLength() )
+        {
+            bool bHasSHA256 = false;
+            bool bHasSHA1 = false;
+            for ( sal_Int32 nInd = 0; nInd < aKeys.getLength(); nInd++ )
+            {
+                if ( aKeys[nInd].Name.equals( PACKAGE_ENCRYPTIONDATA_SHA256UTF8 ) )
+                    bHasSHA256 = true;
+                if ( aKeys[nInd].Name.equals( PACKAGE_ENCRYPTIONDATA_SHA1UTF8 ) )
+                    bHasSHA1 = true;
+            }
+
+            if ( !bHasSHA256 || !bHasSHA1 )
+                throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Expected keys are not provided!" ) ), uno::Reference< uno::XInterface >(), 2 );
+        }
+
+        m_aStorageEncryptionKeys = aKeys;
+        m_aEncryptionKey.realloc( 0 );
+    }
+    else if ( aPropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ENCRYPTION_ALGORITHMS_PROPERTY ) ) )
+    {
+        uno::Sequence< beans::NamedValue > aAlgorithms;
+        if ( m_pZipFile || !( aValue >>= aAlgorithms ) || aAlgorithms.getLength() == 0 )
+        {
+            // the algorithms can not be changed if the file has a persistence based on the algorithms ( m_pZipFile )
+            throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "unexpected algorithms list is provided." ) ), uno::Reference< uno::XInterface >(), 2 );
+        }
+
+        for ( sal_Int32 nInd = 0; nInd < aAlgorithms.getLength(); nInd++ )
+        {
+            if ( aAlgorithms[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "StartKeyGenerationAlgorithm" ) ) )
+            {
+                sal_Int32 nID = 0;
+                if ( !( aAlgorithms[nInd].Value >>= nID )
+                  || ( nID != xml::crypto::DigestID::SHA256 && nID != xml::crypto::DigestID::SHA1 ) )
+                    throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Unexpected start key generation algorithm is provided!" ) ), uno::Reference< uno::XInterface >(), 2 );
+
+                m_nStartKeyGenerationID = nID;
+            }
+            else if ( aAlgorithms[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "EncryptionAlgorithm" ) ) )
+            {
+                sal_Int32 nID = 0;
+                if ( !( aAlgorithms[nInd].Value >>= nID )
+                  || ( nID != xml::crypto::CipherID::AES_CBC_W3C_PADDING && nID != xml::crypto::CipherID::BLOWFISH_CFB_8 ) )
+                    throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Unexpected start key generation algorithm is provided!" ) ), uno::Reference< uno::XInterface >(), 2 );
+
+                m_nCommonEncryptionID = nID;
+            }
+            else if ( aAlgorithms[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ChecksumAlgorithm" ) ) )
+            {
+                sal_Int32 nID = 0;
+                if ( !( aAlgorithms[nInd].Value >>= nID )
+                  || ( nID != xml::crypto::DigestID::SHA1_1K && nID != xml::crypto::DigestID::SHA256_1K ) )
+                    throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "Unexpected start key generation algorithm is provided!" ) ), uno::Reference< uno::XInterface >(), 2 );
+
+                m_nChecksumDigestID = nID;
+            }
+            else
+            {
+                OSL_ENSURE( sal_False, "Unexpected encryption algorithm is provided!" );
+                throw IllegalArgumentException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX "unexpected algorithms list is provided." ) ), uno::Reference< uno::XInterface >(), 2 );
+            }
+        }
     }
     else
         throw UnknownPropertyException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
@@ -1665,32 +1808,41 @@ Any SAL_CALL ZipPackage::getPropertyValue( const OUString& PropertyName )
     //	throw UnknownPropertyException( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( OSL_LOG_PREFIX ) ), uno::Reference< uno::XInterface >() );
 
     Any aAny;
-    if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "EncryptionKey" ) ) )
+    if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( ENCRYPTION_KEY_PROPERTY ) ) )
     {
         aAny <<= m_aEncryptionKey;
         return aAny;
     }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "HasEncryptedEntries" ) ) )
+    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ENCRYPTION_ALGORITHMS_PROPERTY ) ) )
+    {
+        ::comphelper::SequenceAsHashMap aAlgorithms;
+        aAlgorithms[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "StartKeyGenerationAlgorithm" ) ) ] <<= m_nStartKeyGenerationID;
+        aAlgorithms[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "EncryptionAlgorithm" ) ) ] <<= m_nCommonEncryptionID;
+        aAlgorithms[ ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ChecksumAlgorithm" ) ) ] <<= m_nChecksumDigestID;
+        aAny <<= aAlgorithms.getAsConstNamedValueList();
+        return aAny;
+    }
+    if ( PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( STORAGE_ENCRYPTION_KEYS_PROPERTY ) ) )
+    {
+        aAny <<= m_aStorageEncryptionKeys;
+        return aAny;
+    }
+    else if ( PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( HAS_ENCRYPTED_ENTRIES_PROPERTY ) ) )
     {
         aAny <<= m_bHasEncryptedEntries;
         return aAny;
     }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "HasNonEncryptedEntries" ) ) )
+    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( HAS_NONENCRYPTED_ENTRIES_PROPERTY ) ) )
     {
         aAny <<= m_bHasNonEncryptedEntries;
         return aAny;
     }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "IsInconsistent" ) ) )
+    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( IS_INCONSISTENT_PROPERTY ) ) )
     {
         aAny <<= m_bInconsistent;
         return aAny;
     }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "UseManifest" ) ) )
-    {
-        aAny <<= m_bUseManifest;
-        return aAny;
-    }
-    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "MediaTypeFallbackUsed" ) ) )
+    else if (PropertyName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( MEDIATYPE_FALLBACK_USED_PROPERTY ) ) )
     {
         aAny <<= m_bMediaTypeFallbackUsed;
         return aAny;
