@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -48,16 +48,13 @@
 #include <rscdb.hxx>
 #include <rscrsc.hxx>
 
-using namespace rtl;
+using ::rtl::OString;
+using ::rtl::OStringBuffer;
 
 /*************************************************************************
 |*
 |*	  RscTypCont :: RscTypCont
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 27.06.90
-|*
 *************************************************************************/
 RscTypCont :: RscTypCont( RscError * pErrHdl,
                           RSCBYTEORDER_TYPE nOrder,
@@ -67,9 +64,9 @@ RscTypCont :: RscTypCont( RscError * pErrHdl,
       nSourceCharSet( RTL_TEXTENCODING_UTF8 ),
       nByteOrder( nOrder ),
       aSearchPath( rSearchPath ),
-      aBool( pHS->getID( "BOOL" ), RSC_NOTYPE ),
+      aBool( pHS->getID( "sal_Bool" ), RSC_NOTYPE ),
       aShort( pHS->getID( "short" ), RSC_NOTYPE ),
-      aUShort( pHS->getID( "USHORT" ), RSC_NOTYPE ),
+      aUShort( pHS->getID( "sal_uInt16" ), RSC_NOTYPE ),
       aLong( pHS->getID( "long" ), RSC_NOTYPE ),
       aEnumLong( pHS->getID( "enum_long" ), RSC_NOTYPE ),
       aIdUShort( pHS->getID( "IDUSHORT" ), RSC_NOTYPE ),
@@ -83,6 +80,7 @@ RscTypCont :: RscTypCont( RscError * pErrHdl,
       a0to9999Short( pHS->getID( "YearShort" ), RSC_NOTYPE ),
       aIdLong( pHS->getID( "IDLONG" ), RSC_NOTYPE ),
       aString( pHS->getID( "Chars" ), RSC_NOTYPE ),
+      aStringLiteral( pHS->getID( "Chars" ), RSC_NOTYPE ),
       aWinBits( pHS->getID( "WinBits" ), RSC_NOTYPE ),
       aLangType(),
       aLangString( pHS->getID( "Lang_Chars" ), RSC_NOTYPE, &aString, &aLangType ),
@@ -127,7 +125,7 @@ static sal_uInt32 getLangIdAndShortenLocale( RscTypCont* pTypCont,
     else
         rLang = rtl::OString();
 #if OSL_DEBUG_LEVEL > 1
-        fprintf( stderr, " %s (0x%hx)", aL.getStr(), nRet );
+        fprintf( stderr, " %s (0x%hx)", aL.getStr(), (int)nRet );
 #endif
     return nRet;
 }
@@ -145,7 +143,7 @@ ByteString RscTypCont::ChangeLanguage( const ByteString& rNewLang )
         aCountry = aLang.getToken( 0, '-', nIndex );
     if( nIndex != -1 )
         aVariant = aLang.copy( nIndex );
-    
+
     bool bAppendEnUsFallback =
         ! (rNewLang.EqualsIgnoreCaseAscii( "en-US" ) ||
            rNewLang.EqualsIgnoreCaseAscii( "x-no-translate" ) );
@@ -159,7 +157,7 @@ ByteString RscTypCont::ChangeLanguage( const ByteString& rNewLang )
     {
         aLangFallbacks.push_back(getLangIdAndShortenLocale( this, aLg, aCountry, aVariant ) );
     } while( aLg.getLength() );
-    
+
     if( bAppendEnUsFallback )
     {
         aLg = "en";
@@ -185,10 +183,6 @@ Atom RscTypCont::AddLanguage( const char* pLang )
 |*
 |*	  RscTypCont :: ~RscTypCont
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 27.06.90
-|*
 *************************************************************************/
 void DestroyNode( RscTop * pRscTop, ObjNode * pObjNode ){
     if( pObjNode ){
@@ -232,9 +226,6 @@ void Pre_dtorTree( RscTop * pRscTop ){
 }
 
 RscTypCont :: ~RscTypCont(){
-    RscTop	*		pRscTmp;
-    RscSysEntry   * pSysEntry;
-
     // Alle Unterbaeume loeschen
     aVersion.pClass->Destroy( aVersion );
     rtl_freeMemory( aVersion.pData );
@@ -242,11 +233,8 @@ RscTypCont :: ~RscTypCont(){
 
     // Alle Klassen noch gueltig, jeweilige Instanzen freigeben
     // BasisTypen
-    pRscTmp = aBaseLst.First();
-    while( pRscTmp ){
-        pRscTmp->Pre_dtor();
-        pRscTmp = aBaseLst.Next();
-    };
+    for ( size_t i = 0, n = aBaseLst.size(); i < n; ++i )
+        aBaseLst[ i ]->Pre_dtor();
     aBool.Pre_dtor();
     aShort.Pre_dtor();
     aUShort.Pre_dtor();
@@ -264,21 +252,20 @@ RscTypCont :: ~RscTypCont(){
     delete aVersion.pClass;
     DestroyTree( pRoot );
 
-    while( NULL != (pRscTmp = aBaseLst.Remove()) ){
-        delete pRscTmp;
-    };
+    for ( size_t i = 0, n = aBaseLst.size(); i < n; ++i )
+        delete aBaseLst[ i ];
+    aBaseLst.clear();
 
-    while( NULL != (pSysEntry = aSysLst.Remove()) ){
-        delete pSysEntry;
-    };
+    for ( size_t i = 0, n = aSysLst.size(); i < n; ++i )
+        delete aSysLst[ i ];
+    aSysLst.clear();
 }
 
 void RscTypCont::ClearSysNames()
 {
-    RscSysEntry   * pSysEntry;
-    while( NULL != (pSysEntry = aSysLst.Remove()) ){
-        delete pSysEntry;
-    };
+    for ( size_t i = 0, n = aSysLst.size(); i < n; ++i )
+        delete aSysLst[ i ];
+    aSysLst.clear();
 }
 
 //=======================================================================
@@ -317,12 +304,11 @@ RscTop * RscTypCont::SearchType( Atom nId )
     ELSE_IF( aLangString )
     ELSE_IF( aLangShort )
 
-    RscTop * pEle = aBaseLst.First();
-    while( pEle )
+    for ( size_t i = 0, n = aBaseLst.size(); i < n; ++i )
     {
+        RscTop* pEle = aBaseLst[ i ];
         if( pEle->GetId() == nId )
             return pEle;
-        pEle = aBaseLst.Next();
     }
     return NULL;
 }
@@ -331,10 +317,6 @@ RscTop * RscTypCont::SearchType( Atom nId )
 |*
 |*	  RscTypCont :: Search
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 27.06.90
-|*
 *************************************************************************/
 RscTop * RscTypCont :: Search( Atom nRT ){
     return( (RscTop *)pRoot->Search( nRT ) );
@@ -356,10 +338,6 @@ CLASS_DATA RscTypCont :: Search( Atom nRT, const RscId & rId ){
 |*
 |*	  RscTypCont :: Delete()
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 10.07.91
-|*	  Letzte Aenderung	MM 10.07.91
-|*
 *************************************************************************/
 void RscTypCont :: Delete( Atom nRT, const RscId & rId ){
     ObjNode *	pObjNode;
@@ -389,29 +367,29 @@ void RscTypCont :: Delete( Atom nRT, const RscId & rId ){
 |*
 |*	  RscTypCont :: PutSysName()
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 27.06.90
-|*
 *************************************************************************/
 sal_uInt32 RscTypCont :: PutSysName( sal_uInt32 nRscTyp, char * pFileName,
-                                 sal_uInt32 nConst, sal_uInt32 nId, BOOL bFirst )
+                                 sal_uInt32 nConst, sal_uInt32 nId, sal_Bool bFirst )
 {
-    RscSysEntry *	pSysEntry;
-    BOOL			bId1 = FALSE;
+    RscSysEntry *pSysEntry;
+    RscSysEntry *pFoundEntry = NULL;
+    sal_Bool			bId1 = sal_False;
 
-    pSysEntry = aSysLst.First();
-    while( pSysEntry )
+    for ( size_t i = 0, n = aSysLst.size(); i < n; ++i )
     {
+        pSysEntry = aSysLst[ i ];
         if( pSysEntry->nKey == 1 )
-            bId1 = TRUE;
+            bId1 = sal_True;
         if( !strcmp( pSysEntry->aFileName.GetBuffer(), pFileName ) )
-            if( pSysEntry->nRscTyp == nRscTyp
-              && pSysEntry->nTyp == nConst
-              && pSysEntry->nRefId == nId )
+            if(  pSysEntry->nRscTyp == nRscTyp
+              && pSysEntry->nTyp    == nConst
+              && pSysEntry->nRefId  == nId
+                 ) {
+                pFoundEntry = pSysEntry;
                 break;
-        pSysEntry = aSysLst.Next();
+            }
     }
+    pSysEntry = pFoundEntry;
 
     if ( !pSysEntry || (bFirst && !bId1) )
     {
@@ -424,10 +402,10 @@ sal_uInt32 RscTypCont :: PutSysName( sal_uInt32 nRscTyp, char * pFileName,
         if( bFirst && !bId1 )
         {
             pSysEntry->nKey = 1;
-            aSysLst.Insert( pSysEntry, (ULONG)0 );
+            aSysLst.insert( aSysLst.begin(), pSysEntry );
         }
         else
-            aSysLst.Insert( pSysEntry, LIST_APPEND );
+            aSysLst.push_back( pSysEntry );
     }
 
     return pSysEntry->nKey;
@@ -437,12 +415,8 @@ sal_uInt32 RscTypCont :: PutSysName( sal_uInt32 nRscTyp, char * pFileName,
 |*
 |*	  RscTypCont :: WriteInc
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 21.06.90
-|*	  Letzte Aenderung	MM 21.06.90
-|*
 *************************************************************************/
-void RscTypCont :: WriteInc( FILE * fOutput, ULONG lFileKey )
+void RscTypCont :: WriteInc( FILE * fOutput, sal_uLong lFileKey )
 {
     RscFile   * pFName;
 
@@ -468,9 +442,9 @@ void RscTypCont :: WriteInc( FILE * fOutput, ULONG lFileKey )
         pFName = aFileTab.Get( lFileKey );
         if( pFName )
         {
-            pDep = pFName->First();
-            while( pDep )
+            for ( size_t i = 0, n = pFName->aDepLst.size(); i < n; ++i )
             {
+                pDep = pFName->aDepLst[ i ];
                 if( pDep->GetFileKey() != lFileKey )
                 {
                     pFile = aFileTab.GetFile( pDep->GetFileKey() );
@@ -481,7 +455,6 @@ void RscTypCont :: WriteInc( FILE * fOutput, ULONG lFileKey )
                                  pFile->aFileName.GetBuffer() );
                     }
                 }
-                pDep = pFName->Next();
             };
         };
     };
@@ -491,10 +464,6 @@ void RscTypCont :: WriteInc( FILE * fOutput, ULONG lFileKey )
 |*
 |*	  RscTypCont :: Methoden die ueber all Knoten laufen
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 
 class RscEnumerateObj
@@ -504,7 +473,7 @@ private:
     ERRTYPE 	aError; 	// Enthaelt den ersten Fehler
     RscTypCont* pTypCont;
     FILE *		fOutput;	// AusgabeDatei
-    ULONG		lFileKey;	// Welche src-Datei
+    sal_uLong		lFileKey;	// Welche src-Datei
     RscTop *	pClass;
 
     DECL_LINK( CallBackWriteRc, ObjNode * );
@@ -545,10 +514,6 @@ public:
 |*
 |*	  RscEnumerateObj :: CallBackWriteRc
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 IMPL_LINK( RscEnumerateObj, CallBackWriteRc, ObjNode *, pObjNode )
 {
@@ -556,7 +521,7 @@ IMPL_LINK( RscEnumerateObj, CallBackWriteRc, ObjNode *, pObjNode )
 
     aError = pClass->WriteRcHeader( RSCINST( pClass, pObjNode->GetRscObj() ),
                                      aMem, pTypCont,
-                                     pObjNode->GetRscId(), 0, TRUE );
+                                     pObjNode->GetRscId(), 0, sal_True );
     if( aError.IsError() || aError.IsWarning() )
         pTypCont->pEH->Error( aError, pClass, pObjNode->GetRscId() );
 
@@ -568,10 +533,6 @@ IMPL_LINK( RscEnumerateObj, CallBackWriteRc, ObjNode *, pObjNode )
 |*
 |*	  RscEnumerateObj :: CallBackWriteSrc
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 IMPL_LINK_INLINE_START( RscEnumerateObj, CallBackWriteSrc, ObjNode *, pObjNode )
 {
@@ -589,10 +550,6 @@ IMPL_LINK_INLINE_END( RscEnumerateObj, CallBackWriteSrc, ObjNode *, pObjNode )
 |*
 |*	  RscEnumerateObj :: CallBackWriteCxx
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 IMPL_LINK_INLINE_START( RscEnumerateObj, CallBackWriteCxx, ObjNode *, pObjNode )
 {
@@ -608,10 +565,6 @@ IMPL_LINK_INLINE_END( RscEnumerateObj, CallBackWriteCxx, ObjNode *, pObjNode )
 |*
 |*	  RscEnumerateObj :: CallBackWriteHxx
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 IMPL_LINK_INLINE_START( RscEnumerateObj, CallBackWriteHxx, ObjNode *, pObjNode )
 {
@@ -627,10 +580,6 @@ IMPL_LINK_INLINE_END( RscEnumerateObj, CallBackWriteHxx, ObjNode *, pObjNode )
 |*
 |*	  RscEnumerateObj :: WriteRcFile
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 void RscEnumerateObj :: WriteRcFile( RscWriteRc & rMem, FILE * fOut ){
     // Definition der Struktur, aus denen die Resource aufgebaut ist
@@ -651,18 +600,18 @@ void RscEnumerateObj :: WriteRcFile( RscWriteRc & rMem, FILE * fOut ){
 
     if( nRT == RSC_VERSIONCONTROL )
     { // kommt immmer als letztes
-        INT32 nCount = pTypCont->aIdTranslator.size();
+        sal_Int32 nCount = pTypCont->aIdTranslator.size();
         // groesse der Tabelle
-        UINT32 nSize = (nCount * (sizeof(sal_uInt64)+sizeof(INT32))) + sizeof(INT32);
+        sal_uInt32 nSize = (nCount * (sizeof(sal_uInt64)+sizeof(sal_Int32))) + sizeof(sal_Int32);
 
         rMem.Put( nCount ); //Anzahl speichern
-        for( std::map< sal_uInt64, ULONG >::const_iterator it =
+        for( std::map< sal_uInt64, sal_uLong >::const_iterator it =
              pTypCont->aIdTranslator.begin(); it != pTypCont->aIdTranslator.end(); ++it )
         {
             // Schluessel schreiben
             rMem.Put( it->first );
             // Objekt Id oder Position schreiben
-            rMem.Put( (INT32)it->second );
+            rMem.Put( (sal_Int32)it->second );
         }
         rMem.Put( nSize ); // Groesse hinten Speichern
     }
@@ -704,7 +653,7 @@ public:
         return aEnumObj.aError;
     };
 
-    ERRTYPE WriteSrc( ULONG lFileKey )
+    ERRTYPE WriteSrc( sal_uLong lFileKey )
     {
         aEnumObj.lFileKey = lFileKey;
 
@@ -713,7 +662,7 @@ public:
         return aEnumObj.aError;
     }
 
-    ERRTYPE WriteCxx( ULONG lFileKey )
+    ERRTYPE WriteCxx( sal_uLong lFileKey )
     {
         aEnumObj.lFileKey = lFileKey;
 
@@ -722,7 +671,7 @@ public:
         return aEnumObj.aError;
     }
 
-    ERRTYPE WriteHxx(  ULONG lFileKey )
+    ERRTYPE WriteHxx(  sal_uLong lFileKey )
     {
         aEnumObj.lFileKey = lFileKey;
 
@@ -748,10 +697,6 @@ public:
 |*
 |*	  RscRscEnumerateRef :: CallBack...
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 IMPL_LINK_INLINE_START( RscEnumerateRef, CallBackWriteRc, RscTop *, pRef )
 {
@@ -796,10 +741,6 @@ IMPL_LINK_INLINE_END( RscEnumerateRef, CallBackWriteRcCtor, RscTop *, pRef )
 |*
 |*	  RscTypCont :: WriteRc
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 22.07.91
-|*
 *************************************************************************/
 
 ERRTYPE RscTypCont::WriteRc( WriteRcContext& rContext )
@@ -815,9 +756,9 @@ ERRTYPE RscTypCont::WriteRc( WriteRcContext& rContext )
 
     // version control
     RscWriteRc aMem( nByteOrder );
-    aVersion.pClass->WriteRcHeader( aVersion, aMem, this, RscId( RSCVERSION_ID ), 0, TRUE );
+    aVersion.pClass->WriteRcHeader( aVersion, aMem, this, RscId( RSCVERSION_ID ), 0, sal_True );
     aEnumRef.aEnumObj.WriteRcFile( aMem, rContext.fOutput );
-        
+
     return aError;
 }
 
@@ -825,13 +766,9 @@ ERRTYPE RscTypCont::WriteRc( WriteRcContext& rContext )
 |*
 |*	  RscTypCont :: WriteSrc
 |*
-|*	  Beschreibung		RES.DOC
-|*	  Ersterstellung	MM 22.03.90
-|*	  Letzte Aenderung	MM 27.06.90
-|*
 *************************************************************************/
-void RscTypCont :: WriteSrc( FILE * fOutput, ULONG nFileKey,
-                             CharSet /*nCharSet*/, BOOL bName )
+void RscTypCont :: WriteSrc( FILE * fOutput, sal_uLong nFileKey,
+                             CharSet /*nCharSet*/, sal_Bool bName )
 {
     RscFile 	*	pFName;
     RscEnumerateRef aEnumRef( this, pRoot, fOutput );
@@ -863,7 +800,7 @@ void RscTypCont :: WriteSrc( FILE * fOutput, ULONG nFileKey,
     }
     else
     {
-        RscId::SetNames( FALSE );
+        RscId::SetNames( sal_False );
         if( NOFILE_INDEX == nFileKey )
         {
             pFName = aFileTab.First();
@@ -883,12 +820,8 @@ void RscTypCont :: WriteSrc( FILE * fOutput, ULONG nFileKey,
 |*
 |*	  RscTypCont :: WriteHxx
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 30.05.91
-|*	  Letzte Aenderung	MM 30.05.91
-|*
 *************************************************************************/
-ERRTYPE RscTypCont :: WriteHxx( FILE * fOutput, ULONG nFileKey )
+ERRTYPE RscTypCont :: WriteHxx( FILE * fOutput, sal_uLong nFileKey )
 {
     fprintf( fOutput, "#include <tools/rc.hxx>\n" );
     fprintf( fOutput, "#include <tools/resid.hxx>\n" );
@@ -904,7 +837,7 @@ ERRTYPE RscTypCont :: WriteHxx( FILE * fOutput, ULONG nFileKey )
     fprintf( fOutput, "#include <vcl/fixed.hxx>\n" );
     fprintf( fOutput, "#include <vcl/group.hxx>\n" );
     fprintf( fOutput, "#include <vcl/image.hxx>\n" );
-    fprintf( fOutput, "#include <vcl/imagebtn.hxx>\n" );
+    fprintf( fOutput, "#include <vcl/button.hxx>\n" );
     fprintf( fOutput, "#include <vcl/keycod.hxx>\n" );
     fprintf( fOutput, "#include <vcl/lstbox.hxx>\n" );
     fprintf( fOutput, "#include <vcl/mapmod.hxx>\n" );
@@ -949,12 +882,8 @@ ERRTYPE RscTypCont :: WriteHxx( FILE * fOutput, ULONG nFileKey )
 |*
 |*	  RscTypCont :: WriteCxx
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 30.05.91
-|*	  Letzte Aenderung	MM 30.05.91
-|*
 *************************************************************************/
-ERRTYPE RscTypCont::WriteCxx( FILE * fOutput, ULONG nFileKey,
+ERRTYPE RscTypCont::WriteCxx( FILE * fOutput, sal_uLong nFileKey,
                               const ByteString & rHxxName )
 {
     RscEnumerateRef aEnumRef( this, pRoot, fOutput );
@@ -986,15 +915,11 @@ ERRTYPE RscTypCont::WriteCxx( FILE * fOutput, ULONG nFileKey,
 |*
 |*	  RscTypCont :: WriteSyntax
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 30.05.91
-|*	  Letzte Aenderung	MM 30.05.91
-|*
 *************************************************************************/
 void RscTypCont::WriteSyntax( FILE * fOutput )
 {
-    for( sal_uInt32 i = 0; i < aBaseLst.Count(); i++ )
-        aBaseLst.GetObject( i )->WriteSyntaxHeader( fOutput, this );
+    for( size_t i = 0; i < aBaseLst.size(); i++ )
+        aBaseLst[ i ]->WriteSyntaxHeader( fOutput, this );
     RscEnumerateRef aEnumRef( this, pRoot, fOutput );
     aEnumRef.WriteSyntax();
 }
@@ -1013,21 +938,17 @@ void RscTypCont::WriteRcCtor
 |*
 |*	  RscTypCont :: Delete()
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 09.12.91
-|*	  Letzte Aenderung	MM 09.12.91
-|*
 *************************************************************************/
 class RscDel
 {
-    ULONG lFileKey;
+    sal_uLong lFileKey;
     DECL_LINK( Delete, RscTop * );
 public:
-    RscDel( RscTop * pRoot, ULONG lKey );
+    RscDel( RscTop * pRoot, sal_uLong lKey );
 };
 
 
-inline RscDel::RscDel( RscTop * pRoot, ULONG lKey )
+inline RscDel::RscDel( RscTop * pRoot, sal_uLong lKey )
 {
     lFileKey = lKey;
     pRoot->EnumNodes( LINK( this, RscDel, Delete ) );
@@ -1041,7 +962,7 @@ IMPL_LINK_INLINE_START( RscDel, Delete, RscTop *, pNode )
 }
 IMPL_LINK_INLINE_END( RscDel, Delete, RscTop *, pNode )
 
-void RscTypCont :: Delete( ULONG lFileKey ){
+void RscTypCont :: Delete( sal_uLong lFileKey ){
     // Resourceinstanzen loeschen
     RscDel aDel( pRoot, lFileKey );
     // Defines loeschen
@@ -1052,61 +973,56 @@ void RscTypCont :: Delete( ULONG lFileKey ){
 |*
 |*	  RscTypCont :: MakeConsistent()
 |*
-|*	  Beschreibung
-|*	  Ersterstellung	MM 23.09.91
-|*	  Letzte Aenderung	MM 23.09.91
-|*
 *************************************************************************/
-BOOL IsInstConsistent( ObjNode * pObjNode, RscTop * pRscTop,
-                       RscInconsList * pList )
+sal_Bool IsInstConsistent( ObjNode * pObjNode, RscTop * pRscTop )
 {
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
 
     if( pObjNode ){
         RSCINST aTmpI;
 
-        if( ! IsInstConsistent( (ObjNode*)pObjNode->Left(), pRscTop, pList ) )
-            bRet = FALSE;
+        if( ! IsInstConsistent( (ObjNode*)pObjNode->Left(), pRscTop ) )
+            bRet = sal_False;
 
         aTmpI.pClass = pRscTop;
         aTmpI.pData = pObjNode->GetRscObj();
-        if( ! aTmpI.pClass->IsConsistent( aTmpI, pList ) )
-            bRet = FALSE;
+        if( ! aTmpI.pClass->IsConsistent( aTmpI ) )
+            bRet = sal_False;
 
-        if( ! IsInstConsistent( (ObjNode*)pObjNode->Right(), pRscTop, pList ) )
-            bRet = FALSE;
+        if( ! IsInstConsistent( (ObjNode*)pObjNode->Right(), pRscTop ) )
+            bRet = sal_False;
     };
 
     return( bRet );
 }
 
-BOOL MakeConsistent( RscTop * pRscTop, RscInconsList * pList )
+sal_Bool MakeConsistent( RscTop * pRscTop )
 {
-    BOOL bRet = TRUE;
+    sal_Bool bRet = sal_True;
 
     if( pRscTop ){
-        if( ! ::MakeConsistent( (RscTop*)pRscTop->Left(), pList ) )
-            bRet = FALSE;
+        if( ! ::MakeConsistent( (RscTop*)pRscTop->Left() ) )
+            bRet = sal_False;
 
         if( pRscTop->GetObjNode() ){
             if( ! pRscTop->GetObjNode()->IsConsistent() ){
                 pRscTop->GetObjNode()->OrderTree();
-                if( ! pRscTop->GetObjNode()->IsConsistent( pList ) )
-                    bRet = FALSE;
+                if( ! pRscTop->GetObjNode()->IsConsistent() )
+                    bRet = sal_False;
             }
-            if( ! IsInstConsistent( pRscTop->GetObjNode(), pRscTop, pList ) )
-                bRet = FALSE;
+            if( ! IsInstConsistent( pRscTop->GetObjNode(), pRscTop ) )
+                bRet = sal_False;
         }
 
-        if( ! ::MakeConsistent( (RscTop*)pRscTop->Right(), pList ) )
-            bRet = FALSE;
+        if( ! ::MakeConsistent( (RscTop*)pRscTop->Right() ) )
+            bRet = sal_False;
     };
 
     return bRet;
 }
 
-BOOL RscTypCont :: MakeConsistent( RscInconsList * pList ){
-    return( ::MakeConsistent( pRoot, pList ) );
+sal_Bool RscTypCont :: MakeConsistent(){
+    return( ::MakeConsistent( pRoot ) );
 }
 
 sal_uInt32 RscTypCont::PutTranslatorKey( sal_uInt64 nKey )
