@@ -426,6 +426,8 @@ void ScTabView::GetAreaMoveEndPosition(SCsCOL nMovX, SCsROW nMovY, ScFollowMode
     {
         nNewX = aViewData.GetRefEndX();
         nNewY = aViewData.GetRefEndY();
+        nCurX = aViewData.GetRefStartX();
+        nCurY = aViewData.GetRefStartY();
     }
     else if (IsBlockMode())
     {
