@@ -50,7 +50,7 @@
 #include <rtl/ustrbuf.hxx>
 #include <cppuhelper/factory.hxx>
 #include <vector>
-#include <hash_map>
+#include <boost/unordered_map.hpp>
 
 #include <tools/resmgr.hxx>
 
@@ -119,7 +119,7 @@ struct ScSolverCellEqual
     }
 };
 
-typedef std::hash_map< table::CellAddress, std::vector<double>, ScSolverCellHash, ScSolverCellEqual > ScSolverCellHashMap;
+typedef boost::unordered_map< table::CellAddress, std::vector<double>, ScSolverCellHash, ScSolverCellEqual > ScSolverCellHashMap;
 
 // -----------------------------------------------------------------------
 
@@ -470,7 +470,7 @@ void SAL_CALL SolverComponent::solve() throw(uno::RuntimeException)
                 case sheet::SolverConstraintOperator_GREATER_EQUAL: nConstrType = GE; break;
                 case sheet::SolverConstraintOperator_EQUAL:         nConstrType = EQ; break;
                 default:
-                    OSL_ENSURE( false, "unexpected enum type" );
+                    OSL_FAIL( "unexpected enum type" );
             }
             add_constraint( lp, pValues, nConstrType, fRightValue );
 
@@ -559,13 +559,13 @@ void SAL_CALL SolverComponent::solve() throw(uno::RuntimeException)
 uno::Sequence< OUString > SolverComponent_getSupportedServiceNames()
 {
     uno::Sequence< OUString > aServiceNames( 1 );
-    aServiceNames[ 0 ] = OUString::createFromAscii( "com.sun.star.sheet.Solver" );
+    aServiceNames[ 0 ] = OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sheet.Solver" ));
     return aServiceNames;
 }
 
 OUString SolverComponent_getImplementationName()
 {
-    return OUString::createFromAscii( "com.sun.star.comp.Calc.Solver" );
+    return OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.comp.Calc.Solver" ));
 }
 
 OUString SAL_CALL SolverComponent::getImplementationName() throw(uno::RuntimeException)
@@ -602,36 +602,6 @@ extern "C"
         *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
     }
 
-    // -------------------------------------------------------------------------
-    
-    SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo( void* /*pServiceManager*/, void* pRegistryKey )
-    {
-        if (pRegistryKey)
-        {
-            try
-            {
-                uno::Reference<registry::XRegistryKey> xNewKey;
-                sal_Int32                              nPos;
-
-                xNewKey = reinterpret_cast< registry::XRegistryKey * >( pRegistryKey )->createKey( SolverComponent_getImplementationName() );
-                xNewKey = xNewKey->createKey( OUString::createFromAscii( "/UNO/SERVICES" ) );
-                const uno::Sequence< OUString > & rSNL1 = SolverComponent_getSupportedServiceNames();
-                const OUString * pArray1 = rSNL1.getConstArray();
-                for ( nPos = rSNL1.getLength(); nPos--; )
-                    xNewKey->createKey( pArray1[nPos] );
-
-                return sal_True;
-            }
-            catch (registry::InvalidRegistryException &)
-            {
-                OSL_ENSURE( sal_False, "### InvalidRegistryException!" );
-            }
-        }
-        return sal_False;
-    }
-
-    // -------------------------------------------------------------------------
-
     SAL_DLLPUBLIC_EXPORT void* SAL_CALL component_getFactory( const sal_Char * pImplName, void * pServiceManager, void * /*pRegistryKey*/ )
     {
         OUString    aImplName( OUString::createFromAscii( pImplName ) );
