@@ -60,8 +60,6 @@
 #include <com/sun/star/util/XModifiable.hpp>
 #include <com/sun/star/container/XChild.hpp>
 #include <com/sun/star/ucb/XSimpleFileAccess.hpp>
-
-
 #include <com/sun/star/script/provider/XScript.hpp>
 #include <com/sun/star/script/provider/XScriptProvider.hpp>
 #include <com/sun/star/script/provider/XScriptProviderSupplier.hpp>
@@ -109,6 +107,8 @@ using namespace ::com::sun::star::container;
 #include <rtl/bootstrap.hxx>
 #include <vcl/svapp.hxx>
 #include <framework/interaction.hxx>
+#include <framework/documentundoguard.hxx>
+#include <comphelper/interaction.hxx>
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/documentconstants.hxx>
 
@@ -117,7 +117,7 @@ using namespace ::com::sun::star::container;
 #include "appdata.hxx"
 #include <sfx2/request.hxx>
 #include <sfx2/bindings.hxx>
-#include "sfxresid.hxx"
+#include "sfx2/sfxresid.hxx"
 #include <sfx2/docfile.hxx>
 #include <sfx2/docfilt.hxx>
 #include <sfx2/objsh.hxx>
@@ -131,7 +131,6 @@ using namespace ::com::sun::star::container;
 #include <sfx2/ctrlitem.hxx>
 #include "arrdecl.hxx"
 #include <sfx2/module.hxx>
-#include <sfx2/macrconf.hxx>
 #include <sfx2/docfac.hxx>
 #include "helper.hxx"
 #include "doc.hrc"
@@ -170,7 +169,7 @@ public:
 
 //=========================================================================
 
-sal_uInt16 __READONLY_DATA aTitleMap_Impl[3][2] =
+sal_uInt16 const aTitleMap_Impl[3][2] =
 {
                                 //	local				remote
     /*	SFX_TITLE_CAPTION	*/	{ 	SFX_TITLE_FILENAME, SFX_TITLE_TITLE },
@@ -228,25 +227,6 @@ void SfxObjectShell::FlushDocInfo()
     sal_Int32 delay(xDocProps->getAutoloadSecs());
     SetAutoLoad( INetURLObject(url), delay * 1000,
                  (delay > 0) || url.getLength() );
-/*
-    // bitte beachten:
-    // 1. Titel in DocInfo aber nicht am Doc (nach HTML-Import)
-    // 	=> auch am Doc setzen
-    // 2. Titel in DocInfo leer (Briefumschlagsdruck)
-    //	=> nicht am Doc setzen, da sonst "unbenanntX" daraus wird
-    String aDocInfoTitle = GetDocInfo().GetTitle();
-    if ( aDocInfoTitle.Len() )
-        SetTitle( aDocInfoTitle );
-    else
-    {
-        pImp->aTitle.Erase();
-        SetNamedVisibility_Impl();
-        if ( GetMedium() )
-        {
-            SfxShell::SetName( GetTitle(SFX_TITLE_APINAME) );
-            Broadcast( SfxSimpleHint(SFX_HINT_TITLECHANGED) );
-        }
-    }*/
 }
 
 //-------------------------------------------------------------------------
@@ -316,7 +296,7 @@ void SfxObjectShell::EnableSetModified( sal_Bool bEnable )
 {
 #ifdef DBG_UTIL
     if ( bEnable == pImp->m_bEnableSetModified )
-        DBG_WARNING( "SFX_PERSIST: EnableSetModified 2x mit dem gleichen Wert gerufen" );
+        DBG_WARNING( "SFX_PERSIST: EnableSetModified 2x called with the same value" );
 #endif
     pImp->m_bEnableSetModified = bEnable;
 }
@@ -374,7 +354,7 @@ void SfxObjectShell::SetModified( sal_Bool bModifiedP )
 {
 #ifdef DBG_UTIL
     if ( !bModifiedP && !IsEnableSetModified() )
-        DBG_WARNING( "SFX_PERSIST: SetModified( sal_False ), obwohl IsEnableSetModified() == sal_False" );
+        DBG_WARNING( "SFX_PERSIST: SetModified( sal_False ), although IsEnableSetModified() == sal_False" );
 #endif
 
     if( !IsEnableSetModified() )
@@ -392,7 +372,7 @@ void SfxObjectShell::SetModified( sal_Bool bModifiedP )
 void SfxObjectShell::ModifyChanged()
 {
     if ( pImp->bClosing )
-        // SetModified aus dem dispose des Models!
+        // SetModified dispose of the models!
         return;
 
     {DBG_CHKTHIS(SfxObjectShell, 0);}
@@ -412,11 +392,10 @@ void SfxObjectShell::ModifyChanged()
 
 sal_Bool SfxObjectShell::IsReadOnlyUI() const
 
-/* 	[Beschreibung]
+/*  [Description]
 
-    Liefert sal_True, wenn das Dokument fuer die UI wie r/o behandelt werden
-    soll. Dieses ist unabhaengig vom tatsaechlichen r/o, welches per
-    <IsReadOnly()> erfragbar ist.
+    Returns sal_True if the document for the UI is treated as r/o. This is
+    regardless of the actual r/o, which can be checked with <IsReadOnly()>.
 */
 
 {
@@ -427,9 +406,9 @@ sal_Bool SfxObjectShell::IsReadOnlyUI() const
 
 sal_Bool SfxObjectShell::IsReadOnlyMedium() const
 
-/* 	[Beschreibung]
+/*  [Description]
 
-    Liefert sal_True, wenn das Medium r/o ist bzw. r/o geoeffnet wurde.
+    Returns sal_True when the medium is r/o, for instance when opened as r/o.
 */
 
 {
@@ -442,10 +421,10 @@ sal_Bool SfxObjectShell::IsReadOnlyMedium() const
 
 void SfxObjectShell::SetReadOnlyUI( sal_Bool bReadOnly )
 
-/* 	[Beschreibung]
+/*  [Description]
 
-    Schaltet das Dokument in einen r/o bzw. r/w Zustand ohne es neu
-    zu laden und ohne die Open-Modi des Mediums zu aendern.
+    Turns the document in an r/o and r/w state respectively without reloading
+    it and without changing the open mode of the medium.
 */
 
 {
@@ -454,8 +433,6 @@ void SfxObjectShell::SetReadOnlyUI( sal_Bool bReadOnly )
     if ( bWasRO != IsReadOnly() )
     {
         Broadcast( SfxSimpleHint(SFX_HINT_MODECHANGED) );
-        //if ( pImp->pDocInfo )
-        //	pImp->pDocInfo->SetReadOnly( IsReadOnly() );
     }
 }
 
@@ -499,12 +476,10 @@ sal_Bool SfxObjectShell::IsInModalMode() const
     return pImp->bModalMode || pImp->bRunningMacro;
 }
 
-//<!--Added by PengYunQuan for Validity Cell Range Picker
 sal_Bool SfxObjectShell::AcceptStateUpdate() const
 {
     return !IsInModalMode();
 }
-//-->Added by PengYunQuan for Validity Cell Range Picker
 
 //-------------------------------------------------------------------------
 
@@ -537,17 +512,18 @@ void SfxObjectShell::SetMacroMode_Impl( sal_Bool bModal )
 
 void SfxObjectShell::SetModalMode_Impl( sal_Bool bModal )
 {
-    // nur Broadcasten wenn modifiziert, sonst ggf. Endlosrekursion
+    // Broadcast only if modified, or otherwise it will possibly go into
+    // an endless loop
     if ( !pImp->bModalMode != !bModal )
     {
-        // zentral mitz"ahlen
+        // Central count
         sal_uInt16 &rDocModalCount = SFX_APP()->Get_Impl()->nDocModalMode;
         if ( bModal )
             ++rDocModalCount;
         else
             --rDocModalCount;
 
-        // umschalten
+        // Switch
         pImp->bModalMode = bModal;
         Broadcast( SfxSimpleHint( SFX_HINT_MODECHANGED ) );
     }
@@ -799,41 +775,39 @@ IndexBitSet& SfxObjectShell::GetNoSet_Impl()
 
 void SfxObjectShell::SetTitle
 (
-    const String& rTitle		// der neue Titel des Dokuments
+    const String& rTitle                // the new Document Title
 )
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Mit dieser Methode kann der Titel des Dokuments gesetzt werden.
-    Dieser entspricht initial dem kompletten Dateinamen. Ein Setzen
-    des Titels wirkt jedoch nicht zu"uck auf den Dateinamen; er wird
-    jedoch in den Caption-Bars der MDI-Fenster angezeigt.
+    With this method, the title of the document can be set.
+    This corresponds initially to the full file name. A setting of the
+    title does not affect the file name, but it will be shown in the
+    Caption-Bars of the MDI-window.
 */
 
 {
     DBG_CHKTHIS(SfxObjectShell, 0);
 
-    // nix zu tun?
+    // Nothing to do?
     if ( ( ( HasName() && pImp->aTitle == rTitle )
         || ( !HasName() && GetTitle() == rTitle ) )
       && !IsDocShared() )
         return;
 
     SfxApplication *pSfxApp = SFX_APP();
-    // ggf. die unbenannt-Nummer freigeben
+
+    // If possible relase the unnamed number.
     if ( pImp->bIsNamedVisible && USHRT_MAX != pImp->nVisualDocumentNumber )
     {
         pSfxApp->ReleaseIndex(pImp->nVisualDocumentNumber);
         pImp->bIsNamedVisible = 0;
     }
 
-    // Title setzen
+    // Set Title
     pImp->aTitle = rTitle;
-//  Wieso denn in der DocInfo?
-//	GetDocInfo().SetTitle( rTitle );
-//	FlushDocInfo();
 
-    // Benachrichtigungen
+    // Notification
     if ( GetMedium() )
     {
         SfxShell::SetName( GetTitle(SFX_TITLE_APINAME) );
@@ -854,74 +828,65 @@ String X(const String &rRet)
 #define X(ret) ret
 #endif
 
-//--------------------------------------------------------------------
 //--------------------------------------------------------------------
 String SfxObjectShell::GetTitle
 (
     sal_uInt16	nMaxLength 		/*	0 (default)
-                                der Titel selbst, so wie er ist
+                                the title itself, as it is
 
                                 1 (==SFX_TITLE_FILENAME)
-                                liefert den logischen Dateinamen ohne Pfad
-                                (unter WNT je nach Systemeinstellung ohne
-                                Extension)
+                                provides the logical file name without path
+                                (under WNT depending on the system settings
+                                without extension)
 
                                 2 (==SFX_TITLE_FULLNAME)
-                                liefert den mit komplettem logischen Dateinamen
-                                mit Pfad (remote => ::com::sun::star::util::URL)
+                                provides the logical file names with full path
+                                (remote =>:: com:: sun:: star:: util:: URL)
 
                                 3 (==SFX_TITLE_APINAME)
-                                liefert den logischen Dateinamen ohne Pfad
-                                und Extension
+                                provides the logical filname without path
+                                and extension
 
                                 4 (==SFX_TITLE_DETECT)
-                                liefert den kompletten Titel, falls noch
-                                nicht gesetzt wird aber aus DocInfo oder
-                                dem Namen des Medium erzeugt
+                                provides the complete title, if not set yet
+                                it will be created from DocInfo or the name of
+                                the medium.
 
                                 5 (==SFX_TITLE_CAPTION)
-                                liefert den Titel so, wie MB ihn heute in
-                                der CaptionBar anzeigen m"ochte
+                                provides the Title just like MB now in the
+                                CaptionBar view
 
                                 6 (==SFX_TITLE_PICKLIST)
-                                liefert den Titel so, wie MB ihn heute in
-                                der PickList anzeigen m"ochte
+                                returns the Title, just like MB now would
+                                display it in the in the PickList
 
                                 7 (==SFX_TITLE_HISTORY)
-                                liefert den Titel so, wie MB ihn heute in
-                                der History anzeigen m"ochte
+                                returns the Title just like MB now would
+                                display it in the in the History
 
                                 10 bis USHRT_MAX
-                                liefert maximal 'nMaxLength' Zeichen vom logischen
-                                Dateinamen inkl. Pfad (remote => ::com::sun::star::util::URL)
+                                provides the 'nMaxLength' of the logical
+                                file name including the path
+                                (remote => ::com::sun::star::util::URL)
                                 */
 ) const
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Liefert den Titel bzw. logischen Dateinamen des Dokuments, je nach
+    Returns the title or logical file name of the document, depending on the
     'nMaxLength'.
 
-    Falls der Dateiname mit Pfad verwendet wird, wird die Namensk"urzung durch
-    Ersetzung eines oder mehrerer Directory-Namen durch "..." durchgef"uhrt,
-    URLs werden z.Zt. immer komplett geliefert.
+    If the file name with path is used, the Name shortened by replacing one or
+    more directory names with "...", URLs are currently always returned
+    in complete form.
 */
 
 {
-//    if ( GetCreateMode() == SFX_CREATE_MODE_EMBEDDED )
-//        return String();
     SfxMedium *pMed = GetMedium();
     if ( IsLoading() )
         return String();
 
-/*    if ( !nMaxLength && pImp->pDocInfo )
-    {
-        String aTitle = pImp->pDocInfo->GetTitle();
-        if ( aTitle.Len() )
-            return aTitle;
-    } */
-
-    // Titel erzeugen?
+    // Create Title?
     if ( SFX_TITLE_DETECT == nMaxLength && !pImp->aTitle.Len() )
     {
         static sal_Bool bRecur = sal_False;
@@ -950,38 +915,37 @@ String SfxObjectShell::GetTitle
     else if (SFX_TITLE_APINAME == nMaxLength )
         return X(GetAPIName());
 
-    // Sonderfall Vorlagen:
+    // Special case templates:
     if( IsTemplate() && pImp->aTitle.Len() &&
          ( nMaxLength == SFX_TITLE_CAPTION || nMaxLength == SFX_TITLE_PICKLIST ) )
         return X(pImp->aTitle);
 
-    // Picklist/Caption wird gemappt
+    // Picklist/Caption is mapped
     if ( pMed && ( nMaxLength == SFX_TITLE_CAPTION || nMaxLength == SFX_TITLE_PICKLIST ) )
     {
-        // Wenn ein spezieller Titel beim "Offnen mitgegeben wurde;
-        // wichtig bei URLs, die INET_PROT_FILE verwenden, denn bei denen
-        // wird der gesetzte Titel nicht beachtet.
-        // (s.u., Auswertung von aTitleMap_Impl)
+        // If a specific title was given at open:
+        // important for URLs: use INET_PROT_FILE for which the set title is not
+        // considered. (See below, analysis of aTitleMap_Impl)
         SFX_ITEMSET_ARG( pMed->GetItemSet(), pNameItem, SfxStringItem, SID_DOCINFO_TITLE, sal_False );
         if ( pNameItem )
             return X( pNameItem->GetValue() );
     }
 
-    // noch unbenannt?
-    DBG_ASSERT( !HasName() || pMed, "HasName() aber kein Medium?!?" );
+    // Still unnamed?
+    DBG_ASSERT( !HasName() || pMed, "HasName() but no Medium?!?" );
     if ( !HasName() || !pMed )
     {
-        // schon Titel gesezt?
+        // Title already set?
         if ( pImp->aTitle.Len() )
             return X(pImp->aTitle);
 
-        // mu\s es durchnumeriert werden?
+        // must it be numbered?
         String aNoName( SfxResId( STR_NONAME ) );
         if ( pImp->bIsNamedVisible )
-            // Nummer hintenanh"angen
+            // Append number
             aNoName += String::CreateFromInt32( pImp->nVisualDocumentNumber );
 
-        // Dokument hei\st vorerst 'unbenannt#'
+        // Document called "noname" for the time being
         return X(aNoName);
     }
 
@@ -996,7 +960,7 @@ String SfxObjectShell::GetTitle
         nMaxLength = aTitleMap_Impl[nMaxLength-SFX_TITLE_CAPTION][nRemote];
     }
 
-    // lokale Datei?
+    // Local file?
     if ( aURL.GetProtocol() == INET_PROT_FILE )
     {
         String aName( aURL.HasMark() ? INetURLObject( aURL.GetURLNoMark() ).PathToFileName() : aURL.PathToFileName() );
@@ -1011,7 +975,7 @@ String SfxObjectShell::GetTitle
     }
     else
     {
-        // ::com::sun::star::util::URL-Versionen
+        // ::com::sun::star::util::URL-Versions
         if ( nMaxLength >= SFX_TITLE_MAXLEN )
         {
             String aComplete( aURL.GetMainURL( INetURLObject::NO_DECODE ) );
@@ -1035,7 +999,7 @@ String SfxObjectShell::GetTitle
         else if ( nMaxLength == SFX_TITLE_FULLNAME )
             return X(aURL.GetMainURL( INetURLObject::DECODE_TO_IURI ));
 
-        // ggf. Titel aus Dateiname generieren
+        // Generate Title from file name if possible
         if ( !pImp->aTitle.Len() )
             pImp->aTitle = aURL.GetBase();
 
@@ -1044,7 +1008,7 @@ String SfxObjectShell::GetTitle
             pImp->aTitle = aURL.GetMainURL( INetURLObject::DECODE_WITH_CHARSET );
     }
 
-    // ganzer Titel
+    // Complete Title
     return X(pImp->aTitle);
 }
 
@@ -1052,20 +1016,16 @@ String SfxObjectShell::GetTitle
 
 void SfxObjectShell::InvalidateName()
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Ermittelt den Titel des Dokuments neu aus 'unbenannt', DocInfo-Titel
-    bzw. Dateinamen. Wird nach Laden aus Template oder SaveAs ben"otigt.
+    Returns the title of the new document, DocInfo-Title or
+    File name. Is required for loading from template or SaveAs.
 */
 
 {
-    // Title neu erzeugen
     pImp->aTitle.Erase();
-//	pImp->nVisualDocumentNumber = USHRT_MAX;
-    //GetTitle( SFX_TITLE_DETECT );
     SetName( GetTitle( SFX_TITLE_APINAME ) );
 
-    // Benachrichtigungen
     Broadcast( SfxSimpleHint(SFX_HINT_TITLECHANGED) );
 }
 
@@ -1075,9 +1035,7 @@ void SfxObjectShell::SetNamedVisibility_Impl()
 {
     if ( !pImp->bIsNamedVisible )
     {
-        // Nummer verpassen
         pImp->bIsNamedVisible = sal_True;
-        // ggf. neue Nummer verpassen
         if ( !HasName() && USHRT_MAX == pImp->nVisualDocumentNumber && !pImp->aTitle.Len() )
         {
             pImp->nVisualDocumentNumber = SFX_APP()->GetFreeIndex();
@@ -1112,14 +1070,14 @@ SfxProgress* SfxObjectShell::GetProgress() const
 
 void SfxObjectShell::SetProgress_Impl
 (
-    SfxProgress *pProgress	/*	zu startender <SfxProgress> oder 0, falls
-                                der Progress zur"uckgesetzt werden soll */
+    SfxProgress *pProgress      /* to started <SfxProgress> or 0,
+                                   if the progress is to be reset */
 )
 
-/*	[Beschreibung]
+/*  [Description]
 
-    Interne Methode zum setzen oder zur"ucksetzen des Progress-Modes
-    f"ur diese SfxObjectShell.
+    Internal method to set or reset the Progress modes for
+    SfxObjectShell.
 */
 
 {
@@ -1142,9 +1100,9 @@ void SfxObjectShell::PostActivateEvent_Impl( SfxViewFrame* pFrame )
             sal_uInt16 nId = pImp->nEventId;
             pImp->nEventId = 0;
             if ( nId == SFX_EVENT_OPENDOC )
-                pSfxApp->NotifyEvent(SfxEventHint( nId, GlobalEventConfig::GetEventName(STR_EVENT_OPENDOC), this ), sal_False);
+                pSfxApp->NotifyEvent(SfxViewEventHint( nId, GlobalEventConfig::GetEventName(STR_EVENT_OPENDOC), this, pFrame->GetFrame().GetController() ), sal_False);
             else if (nId == SFX_EVENT_CREATEDOC )
-                pSfxApp->NotifyEvent(SfxEventHint( nId, GlobalEventConfig::GetEventName(STR_EVENT_CREATEDOC), this ), sal_False);
+                pSfxApp->NotifyEvent(SfxViewEventHint( nId, GlobalEventConfig::GetEventName(STR_EVENT_CREATEDOC), this, pFrame->GetFrame().GetController() ), sal_False);
         }
     }
 }
@@ -1160,10 +1118,11 @@ void SfxObjectShell::SetActivateEvent_Impl(sal_uInt16 nId )
 //--------------------------------------------------------------------
 
 void SfxObjectShell::RegisterTransfer( SfxMedium& rMedium )
-/*  [Beschreibung ]
-    Alle Medien, die aufgesetzt werden, um Teile eines Dokumentes zu
-    laden, muessen an der zugehoerigen SfxObjectShell angemeldet
-    werden. So kann dokumentweise abgebrochen werden.  */
+/*  [Description]
+
+    All media, which are placed in order to load parts of a document must be
+    registered by a related SfxObjectShell. Thus documents can be canceled.
+*/
 {
     rMedium.SetReferer( GetMedium()->GetName() );
 }
@@ -1171,9 +1130,10 @@ void SfxObjectShell::RegisterTransfer( SfxMedium& rMedium )
 //-------------------------------------------------------------------------
 
 void SfxObjectShell::PrepareReload( )
-/*  [Beschreibung ]
-    Wird vor dem Reload gerufen und gibt die Moeglichkeit,
-    etwaige Caches zu leeren. */
+/*  [Description]
+
+    Is called before the Reload and gives the opportunity to clear any caches.
+*/
 {
 }
 
@@ -1181,8 +1141,10 @@ void SfxObjectShell::PrepareReload( )
 
 void SfxObjectShell::LockAutoLoad( sal_Bool bLock )
 
-/* 	Verhindert ein evtl. eintreffendes AutoLoad. Wird auch vor AutoLoad
-    eines umgebenden FrameSet beruecksichtigt.
+/*  [Description]
+
+    Prevents an possible occuring autoload. Takes also FrameSet into account.
+    before the autoload.
 */
 
 {
@@ -1194,21 +1156,21 @@ void SfxObjectShell::LockAutoLoad( sal_Bool bLock )
 
 //-------------------------------------------------------------------------
 
-// kann nach frame.cxx gemoved werden, wenn 358+36x-Stand gemerged sind
+// Can be moved to frame.cxx, when 358+36x-State have been merged
 
 sal_Bool SfxFrame::IsAutoLoadLocked_Impl() const
 {
-    // sein einges Doc gelockt?
+    // Its own Docucument is locked?
     const SfxObjectShell* pObjSh = GetCurrentDocument();
     if ( !pObjSh || !pObjSh->IsAutoLoadLocked() )
         return sal_False;
 
-    // seine Childs gelockt?
+    // Its Childs are locked?
     for ( sal_uInt16 n = GetChildFrameCount(); n--; )
         if ( !GetChildFrame(n)->IsAutoLoadLocked_Impl() )
             return sal_False;
 
-    // sonst ist AutoLoad erlaubt
+    // otherwise allow AutoLoad
     return sal_True;
 }
 
@@ -1216,8 +1178,8 @@ sal_Bool SfxFrame::IsAutoLoadLocked_Impl() const
 
 sal_Bool SfxObjectShell::IsAutoLoadLocked() const
 
-/* 	Liefert, ob ein eintreffendes AutoLoad ausgefuehrt werden darf. Wird auch
-    vor AutoLoad eines umgebenden FrameSet beruecksichtigt.
+/* Returns whether an Autoload is allowed to be executed. Before the
+   surrounding FrameSet of the AutoLoad is also taken into account as well.
 */
 
 {
@@ -1467,7 +1429,7 @@ void SfxObjectShell::TemplateDisconnectionAfterLoad()
         else
         {
             // !TODO/LATER: what's this?!
-            // Interaktiv ( DClick, Contextmenu ) kommt kein Langname mit
+            // Interactiv ( DClick, Contextmenu ) no long name is included
             aTemplateName = getDocProperties()->getTitle();
             if ( !aTemplateName.Len() )
             {
@@ -1557,8 +1519,10 @@ void SfxObjectShell::PositionView_Impl()
 //-------------------------------------------------------------------------
 
 sal_Bool SfxObjectShell::IsLoading() const
-/*  [Beschreibung ]
-    Has FinishedLoading been called? */
+/*  [Description]
+
+    Has FinishedLoading been called?
+*/
 {
     return !( pImp->nLoadedFlags & SFX_LOADED_MAINDOCUMENT );
 }
@@ -1566,23 +1530,17 @@ sal_Bool SfxObjectShell::IsLoading() const
 //-------------------------------------------------------------------------
 
 void SfxObjectShell::CancelTransfers()
-/*  [Beschreibung ]
-    Hier koennen Transfers gecanceled werden, die nicht mit
-    RegisterTransfer registiert wurden */
+/*  [Description]
+
+    Here can Transfers get canceled, which were not regestered
+    by RegisterTransfer.
+*/
 {
     if( ( pImp->nLoadedFlags & SFX_LOADED_ALL ) != SFX_LOADED_ALL )
     {
         AbortImport();
         if( IsLoading() )
             FinishedLoading( SFX_LOADED_ALL );
-
-/*
-        SfxViewFrame* pFrame = SfxViewFrame::GetFirst( this );
-        while( pFrame )
-        {
-            pFrame->CancelTransfers();
-            pFrame = SfxViewFrame::GetNext( *pFrame, this );
-        }*/
     }
 }
 
@@ -1603,10 +1561,10 @@ void AutoReloadTimer_Impl::Timeout()
 
     if ( pFrame )
     {
-        // momentan nicht m"oglich/sinnvoll?
+        // Not possible/meanigfull at the moment?
         if ( !pObjSh->CanReload_Impl() || pObjSh->IsAutoLoadLocked() || Application::IsUICaptured() )
         {
-            // erneuten Versuch erlauben
+            // Allow a retry
             Start();
             return;
         }
@@ -1631,15 +1589,8 @@ SfxModule* SfxObjectShell::GetModule() const
     return GetFactory().GetModule();
 }
 
-sal_Bool SfxObjectShell::IsBasic(
-    const String & rCode, SbxObject * pVCtrl )
-{
-    if( !rCode.Len() ) return sal_False;
-    return SfxMacroConfig::IsBasic( pVCtrl, rCode, GetBasicManager() );
-}
-
 ErrCode SfxObjectShell::CallBasic( const String& rMacro,
-    const String& rBasic, SbxObject* pVCtrl, SbxArray* pArgs,
+    const String& rBasic, SbxArray* pArgs,
     SbxValue* pRet )
 {
     SfxApplication* pApp = SFX_APP();
@@ -1649,23 +1600,13 @@ ErrCode SfxObjectShell::CallBasic( const String& rMacro,
             return ERRCODE_IO_ACCESSDENIED;
     }
 
-    pApp->EnterBasicCall();
     BasicManager *pMgr = GetBasicManager();
     if( pApp->GetName() == rBasic )
         pMgr = pApp->GetBasicManager();
-    ErrCode nRet = SfxMacroConfig::Call( pVCtrl, rMacro, pMgr, pArgs, pRet );
-    pApp->LeaveBasicCall();
+    ErrCode nRet = SfxApplication::CallBasic( rMacro, pMgr, pArgs, pRet );
     return nRet;
 }
 
-ErrCode SfxObjectShell::Call( const String & rCode, sal_Bool bIsBasicReturn, SbxObject * pVCtrl )
-{
-    ErrCode nErr = ERRCODE_NONE;
-    if ( bIsBasicReturn )
-        CallBasic( rCode, String(), pVCtrl );
-    return nErr;
-}
-
 namespace
 {
     static bool lcl_isScriptAccessAllowed_nothrow( const Reference< XInterface >& _rxScriptContext )
@@ -1719,6 +1660,9 @@ ErrCode SfxObjectShell::CallXScript( const Reference< XInterface >& _rxScriptCon
             xScriptProvider.set( xScriptProviderFactory->createScriptProvider( makeAny( _rxScriptContext ) ), UNO_SET_THROW );
         }
 
+        // ry to protect the invocation context's undo manager (if present), just in case the script tampers with it
+        ::framework::DocumentUndoGuard aUndoGuard( _rxScriptContext.get() );
+
         // obtain the script, and execute it
         Reference< provider::XScript > xScript( xScriptProvider->getScript( _rScriptURL ), UNO_QUERY_THROW );
         if ( pCaller && pCaller->hasValue() )
@@ -1728,7 +1672,7 @@ ErrCode SfxObjectShell::CallXScript( const Reference< XInterface >& _rxScriptCon
             {
                 Sequence< uno::Any > aArgs( 1 );
                 aArgs[ 0 ] = *pCaller;
-                xProps->setPropertyValue( rtl::OUString::createFromAscii("Caller"), uno::makeAny( aArgs ) );
+                xProps->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Caller")), uno::makeAny( aArgs ) );
             }
         }
         aRet = xScript->invoke( aParams, aOutParamIndex, aOutParam );
@@ -1736,7 +1680,7 @@ ErrCode SfxObjectShell::CallXScript( const Reference< XInterface >& _rxScriptCon
     catch ( const uno::Exception& )
     {
         aException = ::cppu::getCaughtException();
-        bCaughtException = TRUE;
+        bCaughtException = sal_True;
         nErr = ERRCODE_BASIC_INTERNAL_ERROR;
     }
 
@@ -1770,118 +1714,6 @@ ErrCode SfxObjectShell::CallXScript( const String& rScriptURL,
 }
 
 //-------------------------------------------------------------------------
-namespace {
-    using namespace ::com::sun::star::uno;
-
-    //.....................................................................
-    static SbxArrayRef lcl_translateUno2Basic( const void* _pAnySequence )
-    {
-        SbxArrayRef xReturn;
-        if ( _pAnySequence )
-        {
-            // in real it's a sequence of Any (by convention)
-            const Sequence< Any >* pArguments = static_cast< const Sequence< Any >* >( _pAnySequence );
-
-            // do we have arguments ?
-            if ( pArguments->getLength() )
-            {
-                // yep
-                xReturn = new SbxArray;
-                String sEmptyName;
-
-                // loop through the sequence
-                const Any* pArg		=			pArguments->getConstArray();
-                const Any* pArgEnd	= pArg	+	pArguments->getLength();
-
-                for ( sal_uInt16 nArgPos=1; pArg != pArgEnd; ++pArg, ++nArgPos )
-                    // and create a Sb object for every Any
-                    xReturn->Put( GetSbUnoObject( sEmptyName, *pArg ), nArgPos );
-            }
-        }
-        return xReturn;
-    }
-    //.....................................................................
-    void lcl_translateBasic2Uno( const SbxVariableRef& _rBasicValue, void* _pAny )
-    {
-        if ( _pAny )
-            *static_cast< Any* >( _pAny ) = sbxToUnoValue( _rBasicValue );
-    }
-}
-//-------------------------------------------------------------------------
-ErrCode SfxObjectShell::CallStarBasicScript( const String& _rMacroName, const String& _rLocation,
-    const void* _pArguments, void* _pReturn )
-{
-    OSL_TRACE("in CallSBS");
-    SolarMutexGuard aSolarGuard;
-
-    // the arguments for the call
-    SbxArrayRef xMacroArguments = lcl_translateUno2Basic( _pArguments );
-
-    // the return value
-    SbxVariableRef xReturn = _pReturn ? new SbxVariable : NULL;
-
-    // the location (document or application)
-    String sMacroLocation;
-    if ( _rLocation.EqualsAscii( "application" ) )
-        sMacroLocation = SFX_APP()->GetName();
-#ifdef DBG_UTIL
-    else
-        DBG_ASSERT( _rLocation.EqualsAscii( "document" ),
-            "SfxObjectShell::CallStarBasicScript: invalid (unknown) location!" );
-#endif
-
-    // call the script
-    ErrCode eError = CallBasic( _rMacroName, sMacroLocation, NULL, xMacroArguments, xReturn );
-
-    // translate the return value
-    lcl_translateBasic2Uno( xReturn, _pReturn );
-
-    // outta here
-    return eError;
-}
-
-//-------------------------------------------------------------------------
-ErrCode SfxObjectShell::CallScript(
-    const String & rScriptType,
-    const String & rCode,
-    const void *pArgs,
-    void *pRet
-)
-{
-    SolarMutexGuard aSolarGuard;
-    ErrCode nErr = ERRCODE_NONE;
-    if( rScriptType.EqualsAscii( "StarBasic" ) )
-    {
-        // the arguments for the call
-        SbxArrayRef xMacroArguments = lcl_translateUno2Basic( pArgs );
-
-        // the return value
-        SbxVariableRef xReturn = pRet ? new SbxVariable : NULL;
-
-        // call the script
-        nErr = CallBasic( rCode, String(), NULL, xMacroArguments, xReturn );
-
-        // translate the return value
-        lcl_translateBasic2Uno( xReturn, pRet );
-
-        // did this fail because the method was not found?
-        if ( nErr == ERRCODE_BASIC_PROC_UNDEFINED )
-        {	// yep-> look in the application BASIC module
-            nErr = CallBasic( rCode, SFX_APP()->GetName(), NULL, xMacroArguments, xReturn );
-        }
-    }
-    else if( rScriptType.EqualsAscii( "JavaScript" ) )
-    {
-        DBG_ERROR( "JavaScript not allowed" );
-        return 0;
-    }
-    else
-    {
-        DBG_ERROR( "StarScript not allowed" );
-    }
-    return nErr;
-}
-
 SfxFrame* SfxObjectShell::GetSmartSelf( SfxFrame* pSelf, SfxMedium& /*rMedium*/ )
 {
     return pSelf;
@@ -1899,51 +1731,6 @@ void SfxObjectShell::SetFlags( SfxObjectShellFlags eFlags )
     pImp->eFlags = eFlags;
 }
 
-/*
-void SfxObjectShell::SetBaseURL( const String& rURL )
-{
-    pImp->aBaseURL = rURL;
-    pImp->bNoBaseURL = FALSE;
-}
-
-const String& SfxObjectShell::GetBaseURLForSaving() const
-{
-    if ( pImp->bNoBaseURL )
-        return String();
-    return GetBaseURL();
-}
-
-const String& SfxObjectShell::GetBaseURL() const
-{
-    if ( pImp->aBaseURL.Len() )
-        return pImp->aBaseURL;
-    return pMedium->GetBaseURL();
-}
-
-void SfxObjectShell::SetEmptyBaseURL()
-{
-    pImp->bNoBaseURL = TRUE;
-}
-*/
-String SfxObjectShell::QueryTitle( SfxTitleQuery eType ) const
-{
-    String aRet;
-
-    switch( eType )
-    {
-        case SFX_TITLE_QUERY_SAVE_NAME_PROPOSAL:
-        {
-            SfxMedium* pMed = GetMedium();
-            const INetURLObject aObj( pMed->GetName() );
-            aRet = aObj.GetMainURL( INetURLObject::DECODE_TO_IURI );
-            if ( !aRet.Len() )
-                aRet = GetTitle( SFX_TITLE_CAPTION );
-            break;
-        }
-    }
-    return aRet;
-}
-
 void SfxHeaderAttributes_Impl::SetAttributes()
 {
     bAlert = sal_True;
@@ -1989,7 +1776,6 @@ void SfxHeaderAttributes_Impl::SetAttribute( const SvKeyValue& rKV )
         }
         else
         {
-//			DBG_ERROR( "Schlechtes ::com::sun::star::util::DateTime fuer Expired" );
             pDoc->GetMedium()->SetExpired_Impl( Date( 1, 1, 1970 ) );
         }
     }
@@ -2018,7 +1804,7 @@ SvKeyValueIterator* SfxObjectShell::GetHeaderAttributes()
 {
     if( !pImp->xHeaderAttributes.Is() )
     {
-        DBG_ASSERT( pMedium, "Kein Medium" );
+        DBG_ASSERT( pMedium, "No Medium" );
         pImp->xHeaderAttributes = new SfxHeaderAttributes_Impl( this );
     }
     return ( SvKeyValueIterator*) &pImp->xHeaderAttributes;
@@ -2046,7 +1832,7 @@ sal_Bool SfxObjectShell::IsPreview() const
     SFX_ITEMSET_ARG( pMedium->GetItemSet(), pFlags, SfxStringItem, SID_OPTIONS, sal_False);
     if ( pFlags )
     {
-        // Werte auf einzelne Items verteilen
+        // Distributed values among individual items
         String aFileFlags = pFlags->GetValue();
         aFileFlags.ToUpperAscii();
         if ( STRING_NOTFOUND != aFileFlags.Search( 'B' ) )
@@ -2065,11 +1851,11 @@ sal_Bool SfxObjectShell::IsPreview() const
 
 sal_Bool SfxObjectShell::IsSecure()
 {
-    // Wenn globale Warnung an ist, nach Secure-Referer-Liste gehen
+    // When global warning is on, go to Secure-Referer-Liste
     String aReferer = GetMedium()->GetName();
     if ( !aReferer.Len() )
     {
-        // bei neuen Dokumenten das Template als Referer nehmen
+        // for new documents use the template  as reference
         ::rtl::OUString aTempl( getDocProperties()->getTemplateURL() );
         if ( aTempl.getLength() )
             aReferer = INetURLObject( aTempl ).GetMainURL( INetURLObject::NO_DECODE );
@@ -2089,12 +1875,11 @@ sal_Bool SfxObjectShell::IsSecure()
         return sal_False;
 
     if ( aOpt.IsSecureURL( aURL.GetMainURL( INetURLObject::NO_DECODE ), aReferer ) )
-    //if ( SvtSecurityOptions().IsSecureURL( aURL.GetMainURL( INetURLObject::NO_DECODE ), aReferer ) )
     {
         if ( GetMedium()->GetContent().is() )
         {
             Any aAny( ::utl::UCBContentHelper::GetProperty( aURL.GetMainURL( INetURLObject::NO_DECODE ), String( RTL_CONSTASCII_USTRINGPARAM("IsProtected")) ) );
-            sal_Bool bIsProtected = FALSE;
+            sal_Bool bIsProtected = sal_False;
             if ( ( aAny >>= bIsProtected ) && bIsProtected )
                 return sal_False;
             else
@@ -2107,7 +1892,7 @@ sal_Bool SfxObjectShell::IsSecure()
         return sal_False;
 }
 
-void SfxObjectShell::SetWaitCursor( BOOL bSet ) const
+void SfxObjectShell::SetWaitCursor( sal_Bool bSet ) const
 {
     for( SfxViewFrame* pFrame = SfxViewFrame::GetFirst( this ); pFrame; pFrame = SfxViewFrame::GetNext( *pFrame, this ) )
     {
@@ -2129,7 +1914,7 @@ String SfxObjectShell::GetAPIName() const
     return aName;
 }
 
-void SfxObjectShell::Invalidate( USHORT nId )
+void SfxObjectShell::Invalidate( sal_uInt16 nId )
 {
     for( SfxViewFrame* pFrame = SfxViewFrame::GetFirst( this ); pFrame; pFrame = SfxViewFrame::GetNext( *pFrame, this ) )
         Invalidate_Impl( pFrame->GetBindings(), nId );
@@ -2152,7 +1937,7 @@ Window* SfxObjectShell::GetDialogParent( SfxMedium* pLoadingMedium )
 {
     Window* pWindow = 0;
     SfxItemSet* pSet = pLoadingMedium ? pLoadingMedium->GetItemSet() : GetMedium()->GetItemSet();
-    SFX_ITEMSET_ARG( pSet, pUnoItem, SfxUnoFrameItem, SID_FILLFRAME, FALSE );
+    SFX_ITEMSET_ARG( pSet, pUnoItem, SfxUnoFrameItem, SID_FILLFRAME, sal_False );
     if ( pUnoItem )
     {
         uno::Reference < frame::XFrame > xFrame( pUnoItem->GetFrame() );
@@ -2162,7 +1947,7 @@ Window* SfxObjectShell::GetDialogParent( SfxMedium* pLoadingMedium )
     if ( !pWindow )
     {
         SfxFrame* pFrame = 0;
-        SFX_ITEMSET_ARG( pSet, pFrameItem, SfxFrameItem, SID_DOCFRAME, FALSE );
+        SFX_ITEMSET_ARG( pSet, pFrameItem, SfxFrameItem, SID_DOCFRAME, sal_False );
         if( pFrameItem && pFrameItem->GetFrame() )
             // get target frame from ItemSet
             pFrame = pFrameItem->GetFrame();
@@ -2196,9 +1981,9 @@ Window* SfxObjectShell::GetDialogParent( SfxMedium* pLoadingMedium )
     return pWindow;
 }
 
-String SfxObjectShell::UpdateTitle( SfxMedium* pMed, USHORT nDocViewNumber )
+String SfxObjectShell::UpdateTitle( SfxMedium* pMed, sal_uInt16 nDocViewNumber )
 {
-    // Titel des Fensters
+    // Title of the windows
     String aTitle;
     if ( pMed )
     {
@@ -2237,29 +2022,29 @@ void SfxObjectShell::SetCreateMode_Impl( SfxObjectCreateMode nMode )
     eCreateMode = nMode;
 }
 
-BOOL SfxObjectShell::IsInPlaceActive()
+sal_Bool SfxObjectShell::IsInPlaceActive()
 {
     if ( eCreateMode != SFX_CREATE_MODE_EMBEDDED )
-        return FALSE;
+        return sal_False;
 
     SfxViewFrame* pFrame = SfxViewFrame::GetFirst( this );
     return pFrame && pFrame->GetFrame().IsInPlace();
 }
 
-BOOL SfxObjectShell::IsUIActive()
+sal_Bool SfxObjectShell::IsUIActive()
 {
     if ( eCreateMode != SFX_CREATE_MODE_EMBEDDED )
-        return FALSE;
+        return sal_False;
 
     SfxViewFrame* pFrame = SfxViewFrame::GetFirst( this );
     return pFrame && pFrame->GetFrame().IsInPlace() && pFrame->GetFrame().GetWorkWindow_Impl()->IsVisible_Impl();
 }
 
-void SfxObjectShell::UIActivate( BOOL )
+void SfxObjectShell::UIActivate( sal_Bool )
 {
 }
 
-void SfxObjectShell::InPlaceActivate( BOOL )
+void SfxObjectShell::InPlaceActivate( sal_Bool )
 {
 }
 
@@ -2275,8 +2060,8 @@ sal_Bool SfxObjectShell::UseInteractionToHandleError(
         {
             uno::Any aInteraction;
             uno::Sequence< uno::Reference< task::XInteractionContinuation > > lContinuations(2);
-            ::framework::ContinuationAbort* pAbort = new ::framework::ContinuationAbort();
-            ::framework::ContinuationApprove* pApprove = new ::framework::ContinuationApprove();
+            ::comphelper::OInteractionAbort* pAbort = new ::comphelper::OInteractionAbort();
+            ::comphelper::OInteractionApprove* pApprove = new ::comphelper::OInteractionApprove();
             lContinuations[0] = uno::Reference< task::XInteractionContinuation >(
                                  static_cast< task::XInteractionContinuation* >( pAbort ), uno::UNO_QUERY );
             lContinuations[1] = uno::Reference< task::XInteractionContinuation >(
@@ -2285,14 +2070,8 @@ sal_Bool SfxObjectShell::UseInteractionToHandleError(
             task::ErrorCodeRequest aErrorCode;
             aErrorCode.ErrCode = nError;
             aInteraction <<= aErrorCode;
-
-            ::framework::InteractionRequest* pRequest = new ::framework::InteractionRequest(aInteraction,lContinuations);
-            uno::Reference< task::XInteractionRequest > xRequest(
-                             static_cast< task::XInteractionRequest* >( pRequest ),
-                             uno::UNO_QUERY);
-
-            xHandler->handle(xRequest);
-            bResult = pAbort->isSelected();
+            xHandler->handle(::framework::InteractionRequest::CreateRequest (aInteraction,lContinuations));
+            bResult = pAbort->wasSelected();
         }
         catch( uno::Exception& )
         {}
