@@ -42,8 +42,8 @@
 #include <svx/svddrag.hxx>
 #include <svx/svdmodel.hxx>
 #include <svx/svdview.hxx>   // fuer RectSnap
-#include "svdglob.hxx"   // StringCache
-#include "svdstr.hrc"    // Objektname
+#include "svx/svdglob.hxx"   // StringCache
+#include "svx/svdstr.hrc"    // Objektname
 #include <svx/svdogrp.hxx>
 #include <svx/svdpage.hxx>
 #include <svx/xflhtit.hxx>
@@ -86,15 +86,15 @@ public:
     ImpCaptParams()
     {
         eType      =SDRCAPT_TYPE3;
-        bFixedAngle=FALSE;
+        bFixedAngle=sal_False;
         nAngle     =4500;
         nGap       =0;
         eEscDir    =SDRCAPT_ESCHORIZONTAL;
-        bEscRel    =TRUE;
+        bEscRel    =sal_True;
         nEscRel    =5000;
         nEscAbs    =0;
         nLineLen   =0;
-        bFitLineLen=TRUE;
+        bFitLineLen=sal_True;
     }
     void CalcEscPos(const Point& rTail, const Rectangle& rRect, Point& rPt, EscDir& rDir) const;
 };
@@ -202,24 +202,24 @@ TYPEINIT1(SdrCaptionObj,SdrRectObj);
 SdrCaptionObj::SdrCaptionObj():
     SdrRectObj(OBJ_TEXT),
     aTailPoly(3),  // Default Groesse: 3 Punkte = 2 Linien
-    mbSpecialTextBoxShadow(FALSE),
-    mbFixedTail(FALSE)
+    mbSpecialTextBoxShadow(sal_False),
+    mbFixedTail(sal_False)
 {
 }
 
 SdrCaptionObj::SdrCaptionObj(const Rectangle& rRect):
     SdrRectObj(OBJ_TEXT,rRect),
     aTailPoly(3),  // Default Groesse: 3 Punkte = 2 Linien
-    mbSpecialTextBoxShadow(FALSE),
-    mbFixedTail(FALSE)
+    mbSpecialTextBoxShadow(sal_False),
+    mbFixedTail(sal_False)
 {
 }
 
 SdrCaptionObj::SdrCaptionObj(const Rectangle& rRect, const Point& rTail):
     SdrRectObj(OBJ_TEXT,rRect),
     aTailPoly(3),  // Default Groesse: 3 Punkte = 2 Linien
-    mbSpecialTextBoxShadow(FALSE),
-    mbFixedTail(FALSE)
+    mbSpecialTextBoxShadow(sal_False),
+    mbFixedTail(sal_False)
 {
     aTailPoly[0]=maFixedTailPos=rTail;
 }
@@ -230,31 +230,30 @@ SdrCaptionObj::~SdrCaptionObj()
 
 void SdrCaptionObj::TakeObjInfo(SdrObjTransformInfoRec& rInfo) const
 {
-    rInfo.bRotateFreeAllowed=FALSE;
-    rInfo.bRotate90Allowed  =FALSE;
-    rInfo.bMirrorFreeAllowed=FALSE;
-    rInfo.bMirror45Allowed  =FALSE;
-    rInfo.bMirror90Allowed  =FALSE;
-    rInfo.bTransparenceAllowed = FALSE;
-    rInfo.bGradientAllowed = FALSE;
-    rInfo.bShearAllowed     =FALSE;
-    rInfo.bEdgeRadiusAllowed=FALSE;
-    rInfo.bCanConvToPath    =TRUE;
-    rInfo.bCanConvToPoly    =TRUE;
-    rInfo.bCanConvToPathLineToArea=FALSE;
-    rInfo.bCanConvToPolyLineToArea=FALSE;
+    rInfo.bRotateFreeAllowed=sal_False;
+    rInfo.bRotate90Allowed  =sal_False;
+    rInfo.bMirrorFreeAllowed=sal_False;
+    rInfo.bMirror45Allowed  =sal_False;
+    rInfo.bMirror90Allowed  =sal_False;
+    rInfo.bTransparenceAllowed = sal_False;
+    rInfo.bGradientAllowed = sal_False;
+    rInfo.bShearAllowed     =sal_False;
+    rInfo.bEdgeRadiusAllowed=sal_False;
+    rInfo.bCanConvToPath    =sal_True;
+    rInfo.bCanConvToPoly    =sal_True;
+    rInfo.bCanConvToPathLineToArea=sal_False;
+    rInfo.bCanConvToPolyLineToArea=sal_False;
     rInfo.bCanConvToContour = (rInfo.bCanConvToPoly || LineGeometryUsageIsNecessary());
 }
 
-UINT16 SdrCaptionObj::GetObjIdentifier() const
+sal_uInt16 SdrCaptionObj::GetObjIdentifier() const
 {
-    return UINT16(OBJ_CAPTION);
+    return sal_uInt16(OBJ_CAPTION);
 }
 
-void SdrCaptionObj::operator=(const SdrObject& rObj)
+SdrCaptionObj* SdrCaptionObj::Clone() const
 {
-    SdrRectObj::operator=(rObj);
-    aTailPoly=((SdrCaptionObj&)rObj).aTailPoly;
+    return CloneHelper< SdrCaptionObj >();
 }
 
 void SdrCaptionObj::TakeObjNameSingul(XubString& rName) const
@@ -560,7 +559,7 @@ void SdrCaptionObj::ImpCalcTail(const ImpCaptParams& rPara, Polygon& rPoly, Rect
 
 bool SdrCaptionObj::BegCreate(SdrDragStat& rStat)
 {
-    if (aRect.IsEmpty()) return FALSE; // Create z.Zt. nur mit vorgegebenen Rect
+    if (aRect.IsEmpty()) return sal_False; // Create z.Zt. nur mit vorgegebenen Rect
 
     ImpCaptParams aPara;
     ImpGetCaptParams(aPara);
@@ -568,7 +567,7 @@ bool SdrCaptionObj::BegCreate(SdrDragStat& rStat)
     aTailPoly[0]=rStat.GetStart();
     ImpCalcTail(aPara,aTailPoly,aRect);
     rStat.SetActionRect(aRect);
-    return TRUE;
+    return sal_True;
 }
 
 bool SdrCaptionObj::MovCreate(SdrDragStat& rStat)
@@ -579,8 +578,8 @@ bool SdrCaptionObj::MovCreate(SdrDragStat& rStat)
     ImpCalcTail(aPara,aTailPoly,aRect);
     rStat.SetActionRect(aRect);
     SetBoundRectDirty();
-    bSnapRectDirty=TRUE;
-    return TRUE;
+    bSnapRectDirty=sal_True;
+    return sal_True;
 }
 
 bool SdrCaptionObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
@@ -595,7 +594,7 @@ bool SdrCaptionObj::EndCreate(SdrDragStat& rStat, SdrCreateCmd eCmd)
 
 bool SdrCaptionObj::BckCreate(SdrDragStat& /*rStat*/)
 {
-    return FALSE;
+    return sal_False;
 }
 
 void SdrCaptionObj::BrkCreate(SdrDragStat& /*rStat*/)
@@ -756,7 +755,7 @@ void SdrCaptionObj::RestGeoData(const SdrObjGeoData& rGeo)
     aTailPoly=rCGeo.aTailPoly;
 }
 
-SdrObject* SdrCaptionObj::DoConvertToPolyObj(BOOL bBezier) const
+SdrObject* SdrCaptionObj::DoConvertToPolyObj(sal_Bool bBezier) const
 { // #42334# - Convert implementiert
     SdrObject* pRect=SdrRectObj::DoConvertToPolyObj(bBezier);
     SdrObject* pTail = ImpConvertMakeObj(basegfx::B2DPolyPolygon(aTailPoly.getB2DPolygon()), sal_False, bBezier);
@@ -818,7 +817,7 @@ void SdrCaptionObj::TRSetBaseGeometry(const basegfx::B2DHomMatrix& rMatrix, cons
             }
             default:
             {
-                DBG_ERROR("TRSetBaseGeometry: Missing unit translation to PoolMetric!");
+                OSL_FAIL("TRSetBaseGeometry: Missing unit translation to PoolMetric!");
             }
         }
     }
