@@ -67,8 +67,8 @@
 #include <viewsh.hxx>
 #include <viewopt.hxx>
 #endif
+#include <sal/types.h>
 
-//#define MAX_DEPTH (USHRT_MAX)
 #define MAX_DEPTH (3)
 
 using namespace ::com::sun::star;
@@ -95,8 +95,8 @@ class SwHTMLWrtTable : public SwWriteTable
                         sal_Bool bTop, sal_Bool bBottom, sal_Bool bLeft, sal_Bool bRight );
 
 public:
-    SwHTMLWrtTable( const SwTableLines& rLines, long nWidth, sal_uInt16 nBWidth,
-                    sal_Bool bRel, USHORT nNumOfRowsToRepeat,
+    SwHTMLWrtTable( const SwTableLines& rLines, long nWidth, sal_uInt32 nBWidth,
+                    sal_Bool bRel, sal_uInt16 nNumOfRowsToRepeat,
                     sal_uInt16 nLeftSub=0, sal_uInt16 nRightSub=0 );
     SwHTMLWrtTable( const SwHTMLTableLayout *pLayoutInfo );
 
@@ -108,7 +108,7 @@ public:
 
 
 SwHTMLWrtTable::SwHTMLWrtTable( const SwTableLines& rLines, long nWidth,
-                                sal_uInt16 nBWidth, sal_Bool bRel, USHORT nNumOfRowsToRepeat,
+                                sal_uInt32 nBWidth, sal_Bool bRel, sal_uInt16 nNumOfRowsToRepeat,
                                 sal_uInt16 nLSub, sal_uInt16 nRSub )
     : SwWriteTable( rLines, nWidth, nBWidth, bRel, MAX_DEPTH, nLSub, nRSub, nNumOfRowsToRepeat )
 {
@@ -155,7 +155,6 @@ sal_Bool SwHTMLWrtTable::HasTabBackground( const SwTableBox& rBox,
         const SvxBrushItem& rBrushItem =
             rBox.GetFrmFmt()->GetBackground();
 
-        /// OD 02.09.2002 #99657#
         /// The table box has a background, if its background color is not "no fill"/
         /// "auto fill" or it has a background graphic.
         bRet = rBrushItem.GetColor() != COL_TRANSPARENT ||
@@ -186,7 +185,6 @@ sal_Bool SwHTMLWrtTable::HasTabBackground( const SwTableLine& rLine,
 
     sal_Bool bRet = sal_False;
     const SvxBrushItem& rBrushItem = rLine.GetFrmFmt()->GetBackground();
-    /// OD 02.09.2002 #99657#
     /// The table line has a background, if its background color is not "no fill"/
     /// "auto fill" or it has a background graphic.
     bRet = rBrushItem.GetColor() != COL_TRANSPARENT ||
@@ -280,16 +278,17 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
     if ( !nRowSpan )
         return;
 
+#ifndef PURE_HTML
     SwWriteTableCol *pCol = aCols[nCol];
+#endif
 
-//	sal_Bool bOutWidth = nColSpan>1 || pCol->GetOutWidth();
-    sal_Bool bOutWidth = sal_True; //nColSpan==1 && pCol->GetOutWidth();
+    sal_Bool bOutWidth = sal_True;
 
     const SwStartNode* pSttNd = pBox->GetSttNd();
     sal_Bool bHead = sal_False;
     if( pSttNd )
     {
-        ULONG nNdPos = pSttNd->GetIndex()+1;
+        sal_uLong nNdPos = pSttNd->GetIndex()+1;
 
         // Art der Zelle (TD/TH) bestimmen
         SwNode* pNd;
@@ -334,7 +333,7 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
 
 #ifndef PURE_HTML
     long nWidth = 0;
-    sal_uInt16 nPrcWidth = USHRT_MAX;
+    sal_uInt32 nPrcWidth = USHRT_MAX;
     if( bOutWidth )
     {
         if( bLayoutExport )
@@ -473,7 +472,9 @@ void SwHTMLWrtTable::OutTableCell( SwHTMLWriter& rWrt,
     }
     else
     {
-        sal_uInt16 nTWidth, nBWidth, nLSub, nRSub;
+        sal_uInt16 nTWidth;
+        sal_uInt32 nBWidth; 
+        sal_uInt16 nLSub, nRSub;
         if( HasRelWidths() )
         {
             nTWidth = 100;
@@ -729,9 +730,6 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             case 4:  pFrame = OOO_STRING_SVTOOLS_HTML_TF_lhs		;break;
             case 8:  pFrame = OOO_STRING_SVTOOLS_HTML_TF_rhs		;break;
             case 12: pFrame = OOO_STRING_SVTOOLS_HTML_TF_vsides	;break;
-            //FRAME=BOX ist der default wenn BORDER>0
-            //case 15:
-            //default: pFrame = OOO_STRING_SVTOOLS_HTML_TF_box		;break; // geht nicht
         };
         if( pFrame )
             (((sOut += ' ' ) += OOO_STRING_SVTOOLS_HTML_O_frame ) += '=') += pFrame;
@@ -834,7 +832,7 @@ void SwHTMLWrtTable::Write( SwHTMLWriter& rWrt, sal_Int16 eAlign,
             ByteString sOutStr( '<' );
             sOutStr += OOO_STRING_SVTOOLS_HTML_col;
 
-            sal_uInt16 nWidth;
+            sal_uInt32 nWidth;
             sal_Bool bRel;
             if( bLayoutExport )
             {
