@@ -113,7 +113,6 @@ SwFilterDetect::~SwFilterDetect()
     // now some parameters that can already be in the array, but may be overwritten or new inserted here
     // remember their indices in the case new values must be added to the array
     sal_Int32 nPropertyCount = lDescriptor.getLength();
-    sal_Int32 nIndexOfFilterName = -1;
     sal_Int32 nIndexOfInputStream = -1;
     sal_Int32 nIndexOfContent = -1;
     sal_Int32 nIndexOfReadOnlyFlag = -1;
@@ -143,10 +142,6 @@ SwFilterDetect::~SwFilterDetect()
         {
             lDescriptor[nProperty].Value >>= sTemp;
             aPreselectedFilterName = sTemp;
-
-            // if the preselected filter name is not correct, it must be erased after detection
-            // remember index of property to get access to it later
-            nIndexOfFilterName = nProperty;
         }
         else if( lDescriptor[nProperty].Name == OUString(RTL_CONSTASCII_USTRINGPARAM("InputStream")) )
             nIndexOfInputStream = nProperty;
@@ -170,14 +165,12 @@ SwFilterDetect::~SwFilterDetect()
             nIndexOfDocumentTitle = nProperty;
     }
 
-    // can't check the type for external filters, so set the "dont" flag accordingly
     SolarMutexGuard aGuard;
-    //SfxFilterFlags nMust = SFX_FILTER_IMPORT, nDont = SFX_FILTER_NOTINSTALLED;
 
     SfxApplication* pApp = SFX_APP();
     SfxAllItemSet *pSet = new SfxAllItemSet( pApp->GetPool() );
     TransformParameters( SID_OPENDOC, lDescriptor, *pSet );
-    SFX_ITEMSET_ARG( pSet, pItem, SfxBoolItem, SID_DOC_READONLY, FALSE );
+    SFX_ITEMSET_ARG( pSet, pItem, SfxBoolItem, SID_DOC_READONLY, sal_False );
 
     bWasReadOnly = pItem && pItem->GetValue();
 
@@ -190,15 +183,14 @@ SwFilterDetect::~SwFilterDetect()
             String aPattern( aPrefix );
             aPattern += String::CreateFromAscii("swriter");
             if ( aURL.Match( aPattern ) >= aPattern.Len() )
-                //pFilter = SfxFilter::GetDefaultFilterFromFactory( aURL );
                 return aTypeName;
         }
     }
     else
     {
         // ctor of SfxMedium uses owner transition of ItemSet
-        SfxMedium aMedium( aURL, bWasReadOnly ? STREAM_STD_READ : STREAM_STD_READWRITE, FALSE, NULL, pSet );
-        aMedium.UseInteractionHandler( TRUE );
+        SfxMedium aMedium( aURL, bWasReadOnly ? STREAM_STD_READ : STREAM_STD_READWRITE, sal_False, NULL, pSet );
+        aMedium.UseInteractionHandler( sal_True );
         if ( aMedium.GetErrorCode() == ERRCODE_NONE )
         {
             // remember input stream and content and put them into the descriptor later
@@ -207,7 +199,7 @@ SwFilterDetect::~SwFilterDetect()
             xContent = aMedium.GetContent();
             bReadOnly = aMedium.IsReadOnly();
 
-            BOOL bIsStorage = aMedium.IsStorage();
+            sal_Bool bIsStorage = aMedium.IsStorage();
             if ( bIsStorage )
             {
                 uno::Reference< embed::XStorage > xStorage = aMedium.GetStorage( sal_False );
@@ -253,7 +245,7 @@ SwFilterDetect::~SwFilterDetect()
                             aTypeName = pPreFilter->GetTypeName();
                         }
 
-                        aTypeName = SfxFilter::GetTypeFromStorage( xStorage, pPreFilter ? pPreFilter->IsOwnTemplateFormat() : FALSE, &aFilterName );
+                        aTypeName = SfxFilter::GetTypeFromStorage( xStorage, pPreFilter ? pPreFilter->IsOwnTemplateFormat() : sal_False, &aFilterName );
                     }
                     catch( lang::WrappedTargetException& aWrap )
                     {
@@ -275,18 +267,17 @@ SwFilterDetect::~SwFilterDetect()
                                 if ( !bRepairPackage )
                                 {
                                     // ask the user whether he wants to try to repair
-                                    RequestPackageReparation* pRequest = new RequestPackageReparation( aDocumentTitle );
-                                    uno::Reference< task::XInteractionRequest > xRequest ( pRequest );
-                                    xInteraction->handle( xRequest );
-                                    bRepairAllowed = pRequest->isApproved();
+                                    RequestPackageReparation aRequest( aDocumentTitle );
+                                    xInteraction->handle( aRequest.GetRequest() );
+                                    bRepairAllowed = aRequest.isApproved();
                                 }
 
                                 if ( !bRepairAllowed )
                                 {
                                     // repair either not allowed or not successful
-                                    NotifyBrokenPackage* pNotifyRequest = new NotifyBrokenPackage( aDocumentTitle );
-                                    uno::Reference< task::XInteractionRequest > xRequest ( pNotifyRequest );
-                                    xInteraction->handle( xRequest );
+                                    // repair either not allowed or not successful
+                                    NotifyBrokenPackage aNotifyRequest( aDocumentTitle );
+                                    xInteraction->handle( aNotifyRequest.GetRequest() );
 
                                     rtl::Reference< ::comphelper::OIHWrapNoFilterDialog > xHandler = new ::comphelper::OIHWrapNoFilterDialog( xInteraction );
                                     if ( nIndexOfInteractionHandler != -1 )
@@ -327,9 +318,9 @@ SwFilterDetect::~SwFilterDetect()
                     else
                         pFilter = SfxFilterMatcher().GetFilter4EA( aTypeName );
 
-                    BOOL bTestWriter = !pFilter || pFilter->GetServiceName().EqualsAscii("com.sun.star.text.TextDocument") ||
+                    sal_Bool bTestWriter = !pFilter || pFilter->GetServiceName().EqualsAscii("com.sun.star.text.TextDocument") ||
                         pFilter->GetServiceName().EqualsAscii("com.sun.star.text.WebDocument");
-                    BOOL bTestGlobal = !pFilter || pFilter->GetServiceName().EqualsAscii("com.sun.star.text.GlobalDocument");
+                    sal_Bool bTestGlobal = !pFilter || pFilter->GetServiceName().EqualsAscii("com.sun.star.text.GlobalDocument");
 
                     const SfxFilter* pOrigFilter = NULL;
                     if ( !bTestWriter && !bTestGlobal && pFilter )
@@ -339,10 +330,10 @@ SwFilterDetect::~SwFilterDetect()
                         // example: HTML filter for Calc
                         pOrigFilter = pFilter;
                         pFilter = SfxFilterMatcher().GetFilter4EA( pFilter->GetTypeName() );
-                        bTestWriter = TRUE;
+                        bTestWriter = sal_True;
                     }
 
-                    ULONG nErr = ERRCODE_NONE;
+                    sal_uLong nErr = ERRCODE_NONE;
                     if ( pFilter || bTestWriter )
                         nErr = DetectFilter( aMedium, &pFilter );
                     if ( nErr != ERRCODE_NONE )
