@@ -265,8 +265,10 @@ int GtkSalDisplay::GetDefaultMonitorNumber() const
     gint nMonitors = gdk_screen_get_n_monitors(pScreen);
     for (gint i = 0; i < nMonitors; ++i)
     {
-        if (g_ascii_strncasecmp (gdk_screen_get_monitor_plug_name(pScreen, i), "LVDS", 4) == 0)
-            return m_aXineramaScreenIndexMap[i];
+        if (g_ascii_strncasecmp (gdk_screen_get_monitor_plug_name(pScreen, i), "LVDS", 4) == 0) {
+            OSL_ASSERT( size_t(i) < m_aXineramaScreenIndexMap.size() );
+            return (size_t(i) < m_aXineramaScreenIndexMap.size()) ? m_aXineramaScreenIndexMap[i] : 0;
+        }
     }
 #endif
     return 0;
@@ -574,6 +576,14 @@ GtkXLib::~GtkXLib()
 #endif
     Yield( true, true );
     StopTimer();
+
+    if (m_pUserEvent)
+    {
+        g_source_destroy (m_pUserEvent);
+        g_source_unref (m_pUserEvent);
+        m_pUserEvent = NULL;
+    }
+
      // sanity check: at this point nobody should be yielding, but wake them
      // up anyway before the condition they're waiting on gets destroyed.
     osl_setCondition( m_aDispatchCondition );
@@ -790,30 +800,36 @@ extern "C"
 
 gboolean GtkXLib::userEventFn(gpointer data)
 {
-    gboolean bContinue;
+
+    gboolean bContinue = FALSE;
     GtkXLib *pThis = (GtkXLib *) data;
-    SalData *pSalData = GetSalData();
 
-    pSalData->m_pInstance->GetYieldMutex()->acquire();
-    pThis->m_pGtkSalDisplay->EventGuardAcquire();
+    GtkData *pGtkData = static_cast<GtkData*>(GetSalData());
 
-    if( !pThis->m_pGtkSalDisplay->HasMoreEvents() )
+    pGtkData->m_pInstance->GetYieldMutex()->acquire();
+
+    if ( pGtkData->GetDisplay() )
     {
-        if( pThis->m_pUserEvent )
+        pThis->m_pGtkSalDisplay->EventGuardAcquire();
+
+        if( !pThis->m_pGtkSalDisplay->HasMoreEvents() )
         {
-            g_source_unref (pThis->m_pUserEvent);
-            pThis->m_pUserEvent = NULL;
+            if( pThis->m_pUserEvent )
+            {
+                g_source_unref (pThis->m_pUserEvent);
+                pThis->m_pUserEvent = NULL;
+            }
+            bContinue = FALSE;
         }
-        bContinue = FALSE;
+        else
+            bContinue = TRUE;
+
+        pThis->m_pGtkSalDisplay->EventGuardRelease();
+
+        pThis->m_pGtkSalDisplay->DispatchInternalEvent();
+
+        pGtkData->m_pInstance->GetYieldMutex()->release();
     }
-    else
-        bContinue = TRUE;
-
-    pThis->m_pGtkSalDisplay->EventGuardRelease();
-
-    pThis->m_pGtkSalDisplay->DispatchInternalEvent();
-
-    pSalData->m_pInstance->GetYieldMutex()->release();
 
     return bContinue;
 }
