@@ -54,7 +54,7 @@
 #include <xmloff/xmltoken.hxx>
 #include <xmloff/nmspmap.hxx>
 
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/tuple/b2dtuple.hxx>
 
@@ -88,16 +88,17 @@ void XMLShapeExport::ImpExportNewTrans(const uno::Reference< beans::XPropertySet
 void XMLShapeExport::ImpExportNewTrans_GetB2DHomMatrix(::basegfx::B2DHomMatrix& rMatrix,
     const uno::Reference< beans::XPropertySet >& xPropSet)
 {
-    // --> OD 2004-08-09 #i28749# - Get <TransformationInHoriL2R>, if it exist
-    // and if the document is exported into the OpenOffice.org file format.
-    // This property only exists at service com::sun::star::text::Shape - the
-    // Writer UNO service for shapes.
-    // This code is needed, because the positioning attributes in the
-    // OpenOffice.org file format are given in horizontal left-to-right layout
-    // regardless the layout direction the shape is in. In the OASIS Open Office
-    // file format the positioning attributes are correctly given in the layout
-    // direction the shape is in. Thus, this code provides the conversion from
-    // the OASIS Open Office file format to the OpenOffice.org file format.
+    /* Get <TransformationInHoriL2R>, if it exist
+       and if the document is exported into the OpenOffice.org file format.
+       This property only exists at service com::sun::star::text::Shape - the
+       Writer UNO service for shapes.
+       This code is needed, because the positioning attributes in the
+       OpenOffice.org file format are given in horizontal left-to-right layout
+       regardless the layout direction the shape is in. In the OASIS Open Office
+       file format the positioning attributes are correctly given in the layout
+       direction the shape is in. Thus, this code provides the conversion from
+       the OASIS Open Office file format to the OpenOffice.org file format. (#i28749#)
+    */
     uno::Any aAny;
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xPropSet->getPropertySetInfo()->hasPropertyByName(
@@ -109,7 +110,6 @@ void XMLShapeExport::ImpExportNewTrans_GetB2DHomMatrix(::basegfx::B2DHomMatrix&
     {
         aAny = xPropSet->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("Transformation")));
     }
-    // <--
     drawing::HomogenMatrix3 aMatrix;
     aAny >>= aMatrix;
 
@@ -181,7 +181,7 @@ void XMLShapeExport::ImpExportNewTrans_FeaturesAndWrite(::basegfx::B2DTuple& rTR
     mrExport.AddAttribute(XML_NAMESPACE_SVG, XML_HEIGHT, aStr);
 
     // decide if transformation is neccessary
-    BOOL bTransformationIsNeccessary(fTRShear != 0.0 || fTRRotate != 0.0);
+    sal_Bool bTransformationIsNeccessary(fTRShear != 0.0 || fTRRotate != 0.0);
 
     if(bTransformationIsNeccessary)
     {
@@ -408,7 +408,7 @@ void XMLShapeExport::ImpExportEvents( const uno::Reference< drawing::XShape >& x
             case presentation::ClickAction_VANISH:          eStrAction = XML_FADE_OUT; break;
             case presentation::ClickAction_SOUND:           eStrAction = XML_SOUND; break;
             default:
-                DBG_ERROR( "unknown presentation::ClickAction found!" );
+                OSL_FAIL( "unknown presentation::ClickAction found!" );
                 eStrAction = XML_UNKNOWN;
         }
 
@@ -564,8 +564,8 @@ void XMLShapeExport::ImpExportDescription( const uno::Reference< drawing::XShape
         OUString aDescription;
 
         uno::Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY_THROW );
-        xProps->getPropertyValue( OUString::createFromAscii( "Title" ) ) >>= aTitle;
-        xProps->getPropertyValue( OUString::createFromAscii( "Description" ) ) >>= aDescription;
+        xProps->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "Title" )) ) >>= aTitle;
+        xProps->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "Description" )) ) >>= aDescription;
 
         if(aTitle.getLength())
         {
@@ -581,7 +581,7 @@ void XMLShapeExport::ImpExportDescription( const uno::Reference< drawing::XShape
     }
     catch( uno::Exception& )
     {
-        DBG_ERROR( "could not export Title and/or Description for shape!" );
+        OSL_FAIL( "could not export Title and/or Description for shape!" );
     }
 }
 
@@ -629,8 +629,8 @@ void XMLShapeExport::ImpExportTextBoxShape(
         uno::Reference< beans::XPropertySetInfo > xPropSetInfo( xPropSet->getPropertySetInfo() );
 
         // presentation attribute (if presentation)
-        sal_Bool bIsPresShape(FALSE);
-        sal_Bool bIsEmptyPresObj(FALSE);
+        sal_Bool bIsPresShape(sal_False);
+        sal_Bool bIsEmptyPresObj(sal_False);
         OUString aStr;
 
         switch(eShapeType)
@@ -638,49 +638,49 @@ void XMLShapeExport::ImpExportTextBoxShape(
             case XmlShapeTypePresSubtitleShape:
             {
                 aStr = GetXMLToken(XML_PRESENTATION_SUBTITLE);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresTitleTextShape:
             {
                 aStr = GetXMLToken(XML_PRESENTATION_TITLE);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresOutlinerShape:
             {
                 aStr = GetXMLToken(XML_PRESENTATION_OUTLINE);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresNotesShape:
             {
                 aStr = GetXMLToken(XML_PRESENTATION_NOTES);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresHeaderShape:
             {
                 aStr = GetXMLToken(XML_HEADER);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresFooterShape:
             {
                 aStr = GetXMLToken(XML_FOOTER);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresSlideNumberShape:
             {
                 aStr = GetXMLToken(XML_PAGE_NUMBER);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             case XmlShapeTypePresDateTimeShape:
             {
                 aStr = GetXMLToken(XML_DATE_TIME);
-                bIsPresShape = TRUE;
+                bIsPresShape = sal_True;
                 break;
             }
             default:
@@ -877,7 +877,7 @@ void XMLShapeExport::ImpExportEllipseShape(
         awt::Size aSize = xShape->getSize();
         sal_Int32 nRx((aSize.Width + 1) / 2);
         sal_Int32 nRy((aSize.Height + 1) / 2);
-        BOOL bCircle(nRx == nRy);
+        sal_Bool bCircle(nRx == nRy);
 
         // Transformation
         ImpExportNewTrans(xPropSet, nFeatures, pRefPoint);
@@ -896,7 +896,7 @@ void XMLShapeExport::ImpExportEllipseShape(
             const double dEndAngle = nEndAngle / 100.0;
 
             // export circle kind
-            SvXMLUnitConverter::convertEnum( sStringBuffer, (USHORT)eKind, aXML_CircleKind_EnumMap );
+            SvXMLUnitConverter::convertEnum( sStringBuffer, (sal_uInt16)eKind, aXML_CircleKind_EnumMap );
             mrExport.AddAttribute(XML_NAMESPACE_DRAW, XML_KIND, sStringBuffer.makeStringAndClear() );
 
             // export start angle
@@ -942,9 +942,9 @@ void XMLShapeExport::ImpExportPolygonShape(
     const uno::Reference< beans::XPropertySet > xPropSet(xShape, uno::UNO_QUERY);
     if(xPropSet.is())
     {
-        BOOL bClosed(eShapeType == XmlShapeTypeDrawPolyPolygonShape
+        sal_Bool bClosed(eShapeType == XmlShapeTypeDrawPolyPolygonShape
             || eShapeType == XmlShapeTypeDrawClosedBezierShape);
-        BOOL bBezier(eShapeType == XmlShapeTypeDrawClosedBezierShape
+        sal_Bool bBezier(eShapeType == XmlShapeTypeDrawClosedBezierShape
             || eShapeType == XmlShapeTypeDrawOpenBezierShape);
 
         // get matrix
@@ -1144,7 +1144,7 @@ void XMLShapeExport::ImpExportGraphicObjectShape(
                 {
                     if( aStr[ 0 ] == '#' )
                     {
-                        aStreamURL = OUString::createFromAscii( "vnd.sun.star.Package:" );
+                        aStreamURL = OUString(RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.Package:" ));
                         aStreamURL = aStreamURL.concat( aStr.copy( 1, aStr.getLength() - 1 ) );
                     }
 
@@ -1286,17 +1286,18 @@ void XMLShapeExport::ImpExportConnectorShape(
     awt::Point aStart(0,0);
     awt::Point aEnd(1,1);
 
-    // --> OD 2004-08-09 #i36248# - Get <StartPositionInHoriL2R> and
-    // <EndPositionInHoriL2R>, if they exist and if the document is exported
-    // into the OpenOffice.org file format.
-    // These properties only exist at service com::sun::star::text::Shape - the
-    // Writer UNO service for shapes.
-    // This code is needed, because the positioning attributes in the
-    // OpenOffice.org file format are given in horizontal left-to-right layout
-    // regardless the layout direction the shape is in. In the OASIS Open Office
-    // file format the positioning attributes are correctly given in the layout
-    // direction the shape is in. Thus, this code provides the conversion from
-    // the OASIS Open Office file format to the OpenOffice.org file format.
+    /* Get <StartPositionInHoriL2R> and
+       <EndPositionInHoriL2R>, if they exist and if the document is exported
+       into the OpenOffice.org file format.
+       These properties only exist at service com::sun::star::text::Shape - the
+       Writer UNO service for shapes.
+       This code is needed, because the positioning attributes in the
+       OpenOffice.org file format are given in horizontal left-to-right layout
+       regardless the layout direction the shape is in. In the OASIS Open Office
+       file format the positioning attributes are correctly given in the layout
+       direction the shape is in. Thus, this code provides the conversion from
+       the OASIS Open Office file format to the OpenOffice.org file format. (#i36248#)
+    */
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xProps->getPropertySetInfo()->hasPropertyByName(
             OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) &&
@@ -1311,7 +1312,6 @@ void XMLShapeExport::ImpExportConnectorShape(
         xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPosition"))) >>= aStart;
         xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPosition"))) >>= aEnd;
     }
-    // <--
 
     if( pRefPoint )
     {
@@ -1458,17 +1458,18 @@ void XMLShapeExport::ImpExportMeasureShape(
     awt::Point aStart(0,0);
     awt::Point aEnd(1,1);
 
-    // --> OD 2004-08-09 #i36248# - Get <StartPositionInHoriL2R> and
-    // <EndPositionInHoriL2R>, if they exist and if the document is exported
-    // into the OpenOffice.org file format.
-    // These properties only exist at service com::sun::star::text::Shape - the
-    // Writer UNO service for shapes.
-    // This code is needed, because the positioning attributes in the
-    // OpenOffice.org file format are given in horizontal left-to-right layout
-    // regardless the layout direction the shape is in. In the OASIS Open Office
-    // file format the positioning attributes are correctly given in the layout
-    // direction the shape is in. Thus, this code provides the conversion from
-    // the OASIS Open Office file format to the OpenOffice.org file format.
+    /* Get <StartPositionInHoriL2R> and
+       <EndPositionInHoriL2R>, if they exist and if the document is exported
+       into the OpenOffice.org file format.
+       These properties only exist at service com::sun::star::text::Shape - the
+       Writer UNO service for shapes.
+       This code is needed, because the positioning attributes in the
+       OpenOffice.org file format are given in horizontal left-to-right layout
+       regardless the layout direction the shape is in. In the OASIS Open Office
+       file format the positioning attributes are correctly given in the layout
+       direction the shape is in. Thus, this code provides the conversion from
+       the OASIS Open Office file format to the OpenOffice.org file format. (#i36248#)
+    */
     if ( ( GetExport().getExportFlags() & EXPORT_OASIS ) == 0 &&
          xProps->getPropertySetInfo()->hasPropertyByName(
             OUString(RTL_CONSTASCII_USTRINGPARAM("StartPositionInHoriL2R"))) &&
@@ -1483,7 +1484,6 @@ void XMLShapeExport::ImpExportMeasureShape(
         xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("StartPosition"))) >>= aStart;
         xProps->getPropertyValue(OUString(RTL_CONSTASCII_USTRINGPARAM("EndPosition"))) >>= aEnd;
     }
-    // <--
 
     if( pRefPoint )
     {
@@ -1593,7 +1593,7 @@ void XMLShapeExport::ImpExportOLE2Shape(
                 {
                     // OOo internal links have no storage persistance, URL is stored in the XML file
                     // the result LinkURL is empty in case the object is not a link
-                    xPropSet->getPropertyValue( OUString::createFromAscii( "LinkURL" ) ) >>= sURL;
+                    xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "LinkURL" )) ) >>= sURL;
                 }
 
                 xPropSet->getPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM( "PersistName" ) ) ) >>= sPersistName;
