@@ -30,16 +30,20 @@
 #include "precompiled_xmloff.hxx"
 
 #include <xmloff/PageMasterStyleMap.hxx>
-#include "xmlnmspe.hxx"
+#include "xmloff/xmlnmspe.hxx"
 #include <xmloff/xmltoken.hxx>
 
 using namespace ::xmloff::token;
 
-#define _MAP(name,prefix,token,type,context)  { name, sizeof(name)-1, prefix, token, type, context, SvtSaveOptions::ODFVER_010 }
+#define MAP(name,prefix,token,type,context,version)  { name, sizeof(name)-1, prefix, token, type, context, version }
 #define PLMAP(name,prefix,token,type,context) \
-        _MAP(name,prefix,token,type|XML_TYPE_PROP_PAGE_LAYOUT,context)
+        MAP(name,prefix,token,type|XML_TYPE_PROP_PAGE_LAYOUT,context, SvtSaveOptions::ODFVER_010)
+#define PLMAP_12(name,prefix,token,type,context) \
+        MAP(name,prefix,token,type|XML_TYPE_PROP_PAGE_LAYOUT,context, SvtSaveOptions::ODFVER_012)
+#define PLMAP_EX(name,prefix,token,type,context) \
+        MAP(name,prefix,token,type|XML_TYPE_PROP_PAGE_LAYOUT,context, SvtSaveOptions::ODFVER_LATEST)
 #define HFMAP(name,prefix,token,type,context) \
-        _MAP(name,prefix,token,type|XML_TYPE_PROP_HEADER_FOOTER,context)
+        MAP(name,prefix,token,type|XML_TYPE_PROP_HEADER_FOOTER,context, SvtSaveOptions::ODFVER_010)
         
 //______________________________________________________________________________
 
@@ -109,10 +113,14 @@ const XMLPropertyMapEntry aXMLPageMasterStyleMap[] =
     PLMAP( "GridDisplay", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_DISPLAY, XML_TYPE_BOOL, 0 ),
 
     //text grid enhancement for better CJK support
-    PLMAP( "GridBaseWidth", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_BASE_WIDTH, XML_TYPE_MEASURE, CTP_PM_GRID_BASE_WIDTH ),
-    PLMAP( "GridSnapToChars", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_SNAP_TO_CHARS, XML_TYPE_BOOL, CTP_PM_GRID_SNAP_TO_CHARS ),
+    PLMAP_12( "GridBaseWidth", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_BASE_WIDTH, XML_TYPE_MEASURE, CTP_PM_GRID_BASE_WIDTH ),
+    PLMAP_12( "GridSnapToChars", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_SNAP_TO, XML_TYPE_BOOL, CTP_PM_GRID_SNAP_TO ),
+    // fdo#44073: layout-grid-snap-to-characters does not exist in ODF:
+    // write this in extended mode purely for backward compatibility so old
+    // OOo/LO versions that don't understand layout-grid-snap-to read it
+    PLMAP_EX( "GridSnapToChars", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_SNAP_TO_CHARS, XML_TYPE_BOOL, CTP_PM_GRID_SNAP_TO_CHARS ),
       //export as a default attribute
-    PLMAP( "StandardPageMode", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_STANDARD_MODE, XML_TYPE_BOOL|MID_FLAG_DEFAULT_ITEM_EXPORT, CTF_PM_STANDARD_MODE ),
+    PLMAP_12( "StandardPageMode", XML_NAMESPACE_STYLE, XML_LAYOUT_GRID_STANDARD_MODE, XML_TYPE_BOOL|MID_FLAG_DEFAULT_ITEM_EXPORT, CTF_PM_STANDARD_MODE ),
     
     PLMAP( "UserDefinedAttributes",	XML_NAMESPACE_TEXT,		XML_XMLNS,						XML_TYPE_ATTRIBUTE_CONTAINER | MID_FLAG_SPECIAL_ITEM, 0 ),
 
@@ -124,6 +132,7 @@ const XMLPropertyMapEntry aXMLPageMasterStyleMap[] =
     PLMAP( "FootnoteLineRelativeWidth", XML_NAMESPACE_STYLE,	XML__EMPTY, 	XML_TYPE_PERCENT8|MID_FLAG_SPECIAL_ITEM,	CTF_PM_FTN_LINE_WIDTH ),
     PLMAP( "FootnoteLineTextDistance", XML_NAMESPACE_STYLE,	XML__EMPTY, 	XML_TYPE_MEASURE|MID_FLAG_SPECIAL_ITEM,	CTF_PM_FTN_LINE_DISTANCE ),
     PLMAP( "FootnoteLineWeight",		XML_NAMESPACE_STYLE,	XML_FOOTNOTE_SEP,	XML_TYPE_MEASURE16|MID_FLAG_ELEMENT_ITEM,	CTF_PM_FTN_LINE_WEIGTH ),
+    PLMAP( "FootnoteLineStyle",		XML_NAMESPACE_STYLE,	XML_EMPTY,	XML_TYPE_STRING|MID_FLAG_ELEMENT_ITEM,	CTF_PM_FTN_LINE_STYLE ),
 
 // header
     HFMAP( "HeaderHeight",				XML_NAMESPACE_SVG,		XML_HEIGHT, 					XML_TYPE_MEASURE,		CTF_PM_HEADERHEIGHT ),
